@@ -63,20 +63,24 @@ import editorwindow
 import gmic
 import gui
 import keyevents
+import keyframeeditcanvas
+import kftoolmode
 import medialog
-import mlt
 import mltenv
 import mltfilters
 import mltplayer
 import mltprofiles
 import mlttransitions
+import modesetting
 import movemodes
 import persistance
 import positionbar
 import preferenceswindow
+import processutils
 import projectaction
 import projectdata
 import projectinfogui
+import propertyeditorbuilder
 import proxyediting
 import render
 import renderconsumer
@@ -85,6 +89,7 @@ import resync
 import sequence
 import shortcuts
 import snapping
+import threading
 import titler
 import tlinewidgets
 import toolsintegration
@@ -94,9 +99,7 @@ import translations
 import undo
 import updater
 import utils
-
-
-import jackaudio
+import workflow
 
 AUTOSAVE_DIR = appconsts.AUTOSAVE_DIR
 AUTOSAVE_FILE = "autosave/autosave"
@@ -113,6 +116,7 @@ splash_timeout_id = -1
 exit_timeout_id = -1
 window_resize_id = -1
 window_state_id = -1
+resize_timeout_id = -1
 
 _log_file = None
 
@@ -127,7 +131,9 @@ def main(root_path):
     # DEBUG: Direct output to log file if log file set
     if _log_file != None:
         log_print_output_to_file()
-    
+
+    print "Application version: " + editorstate.appversion
+
     # Print OS, Python version and GTK+ version
     try:
         os_release_file = open("/etc/os-release","r")
@@ -148,7 +154,6 @@ def main(root_path):
     except:
         editorstate.mlt_version = "0.0.99" # magic string for "not found"
 
-
     #print "SDL version:", str(editorstate.get_sdl_version())
     
     # passing -xdg as a flag will change the user_dir location with XDG_CONFIG_HOME
@@ -160,6 +165,7 @@ def main(root_path):
 
     # Create hidden folders if not present
     user_dir = utils.get_hidden_user_dir_path()
+
     print "User dir:",user_dir
     if not os.path.exists(user_dir):
         os.mkdir(user_dir)
@@ -187,7 +193,7 @@ def main(root_path):
 
     # Load editor prefs and list of recent projects
     editorpersistance.load()
-    if editorpersistance.prefs.dark_theme == True:
+    if editorpersistance.prefs.theme != appconsts.LIGHT_THEME:
         respaths.apply_dark_theme()
     if editorpersistance.prefs.display_all_audio_levels == False:
         editorstate.display_all_audio_levels = False
@@ -204,7 +210,10 @@ def main(root_path):
     # Apr-2017 - SvdB - Keyboard shortcuts
     shortcuts.load_shortcut_files()
     shortcuts.load_shortcuts()
-    
+
+    # We respaths and translations data available so we need to init in a function.
+    workflow.init_data()
+
     # RHEL7/CentOS compatibility fix
     if gtk_version == "3.8.8":
         GObject.threads_init()
@@ -213,10 +222,16 @@ def main(root_path):
     Gdk.threads_init()
     Gdk.threads_enter()
 
-    # Request dark theme if so desired
-    if editorpersistance.prefs.dark_theme == True:
-        Gtk.Settings.get_default().set_property("gtk-application-prefer-dark-theme", True)
+    # Themes
+    if editorpersistance.prefs.theme == appconsts.FLOWBLADE_THEME:
+        success = gui.apply_gtk_css()
+        if not success:
+            editorpersistance.prefs.theme = appconsts.LIGHT_THEME
+            editorpersistance.save()
 
+    if editorpersistance.prefs.theme != appconsts.LIGHT_THEME:
+        Gtk.Settings.get_default().set_property("gtk-application-prefer-dark-theme", True)
+        
     # Load drag'n'drop images
     dnd.init()
 
@@ -226,7 +241,7 @@ def main(root_path):
     editorstate.SCREEN_WIDTH = scr_w
     editorstate.SCREEN_HEIGHT = scr_h
 
-    print scr_w, scr_h
+    print "Screen size:", scr_w, "x", scr_h
     print "Small height:", editorstate.screen_size_small_height()
     print "Small width:",  editorstate.screen_size_small_width()
 
@@ -243,11 +258,12 @@ def main(root_path):
 
     # Init MLT framework
     repo = mlt.Factory().init()
+    processutils.prepare_mlt_repo(repo)
 
-    # Set numeric locale to use "." as radix, MLT initilizes this to OS locale and this causes bugs 
+    # Set numeric locale to use "." as radix, MLT initilizes this to OS locale and this causes bugs.
     locale.setlocale(locale.LC_NUMERIC, 'C')
 
-    # Check for codecs and formats on the system
+    # Check for codecs and formats on the system.
     mltenv.check_available_features(repo)
     renderconsumer.load_render_profiles()
 
@@ -255,13 +271,13 @@ def main(root_path):
     mltfilters.load_filters_xml(mltenv.services)
     mlttransitions.load_compositors_xml(mltenv.transitions)
     
-    # Replace some services if better replacements available
+    # Replace some services if better replacements available.
     mltfilters.replace_services(mltenv.services)
 
-    # Create list of available mlt profiles
+    # Create list of available mlt profiles.
     mltprofiles.load_profile_list()
     
-    # Save assoc file path if found in arguments
+    # Save assoc file path if found in arguments.
     global assoc_file_path
     assoc_file_path = get_assoc_file_path()
         
@@ -270,34 +286,34 @@ def main(root_path):
     editorstate.project = projectdata.get_default_project()
     check_crash = True
 
-    # Audiomonitoring being available needs to be known before GUI creation
+    # Audiomonitoring being available needs to be known before GUI creation.
     audiomonitoring.init(editorstate.project.profile)
 
-    # Set trim view mode to current default value
+    # Set trim view mode to current default value.
     editorstate.show_trim_view = editorpersistance.prefs.trim_view_default
 
-    # Check for tools and init tools integration
+    # Check for tools and init tools integration.
     gmic.test_availablity()
     toolnatron.init()
     toolsintegration.init()
     #toolsintegration.test()
     
-    # Create player object
+    # Create player object.
     create_player()
 
     # Create main window and set widget handles in gui.py for more convenient reference.
     create_gui()
 
-    # Inits widgets with project data
+    # Inits widgets with project data.
     init_project_gui()
 
-    # Inits widgets with current sequence data
+    # Inits widgets with current sequence data.
     init_sequence_gui()
 
     # Launch player now that data and gui exist
     launch_player()
 
-    # Editor and modules need some more initializing
+    # Editor and modules need some more initializing.
     init_editor_state()
 
     # Tracks need to be recentered if window is resized.
@@ -309,8 +325,8 @@ def main(root_path):
     # Get existing autosave files
     autosave_files = get_autosave_files()
 
-    # Clear splash
-    if ((editorpersistance.prefs.display_splash_screen == True) and len(autosave_files) == 0):
+    # Show splash
+    if ((editorpersistance.prefs.display_splash_screen == True) and len(autosave_files) == 0) and not editorstate.runtime_version_greater_then_test_version(editorpersistance.prefs.workflow_dialog_last_version_shown, editorstate.appversion):
         global splash_timeout_id
         splash_timeout_id = GLib.timeout_add(2600, destroy_splash_screen)
         splash_screen.show_all()
@@ -320,7 +336,7 @@ def main(root_path):
     # Every running instance has unique autosave file which is deleted at exit
     set_instance_autosave_id()
 
-    # Existance of autosave file hints that program was exited abnormally
+    # Existance of autosave file hints that program was exited abnormally.
     if check_crash == True and len(autosave_files) > 0:
         if len(autosave_files) == 1:
             GObject.timeout_add(10, autosave_recovery_dialog)
@@ -330,22 +346,32 @@ def main(root_path):
         start_autosave()
 
     # We prefer to monkeypatch some callbacks into some modules, usually to
-    # maintain a simpler and/or non-circular import structure
+    # maintain a simpler and/or non-circular import structure.
     monkeypatch_callbacks()
 
-    # File in assoc_file_path is opened after very short delay
+    # File in assoc_file_path is opened after very short delay.
     if not(check_crash == True and len(autosave_files) > 0):
         if assoc_file_path != None:
             print "Launch assoc file:", assoc_file_path
             global assoc_timeout_id
             assoc_timeout_id = GObject.timeout_add(10, open_assoc_file)
 
+    if editorpersistance.prefs.theme == appconsts.FLOWBLADE_THEME:
+        gui.apply_flowblade_theme_fixes()
+        
     # SDL 2 consumer needs to created after Gtk.main() has run enough for window to be visble
     #if editorstate.get_sdl_version() == editorstate.SDL_2: # needs more state considerion still
     #    print "SDL2 timeout launch"
     #    global sdl2_timeout_id
     #    sdl2_timeout_id = GObject.timeout_add(1500, create_sdl_2_consumer)
-            
+    
+    # In PositionNumericalEntries we are using Gtk.Entry objects in a way that works for us nicely, but is somehow "error" for Gtk, so we just kill this.
+    Gtk.Settings.get_default().set_property("gtk-error-bell", False)
+    
+    # Show first run worflow info dialog if not shown for this version of application.
+    if editorstate.runtime_version_greater_then_test_version(editorpersistance.prefs.workflow_dialog_last_version_shown, editorstate.appversion):
+        GObject.timeout_add(500, show_worflow_info_dialog)
+        
     # Launch gtk+ main loop
     Gtk.main()
 
@@ -362,7 +388,7 @@ def monkeypatch_callbacks():
     render.open_media_file_callback = projectaction.open_rendered_file
 
     # Set callback for undo/redo ops, batcherrender app does not need this 
-    undo.set_post_undo_redo_callback(editevent.set_post_undo_redo_edit_mode)
+    undo.set_post_undo_redo_callback(modesetting.set_post_undo_redo_edit_mode)
     undo.repaint_tline = updater.repaint_tline
 
     # # Drag'n'drop callbacks
@@ -385,6 +411,9 @@ def monkeypatch_callbacks():
     snapping._get_frame_for_x_func = tlinewidgets.get_frame
     snapping._get_x_for_frame_func = tlinewidgets._get_frame_x
 
+    # Callback to reinit to change slider <-> kf editor
+    propertyeditorbuilder.re_init_editors_for_slider_type_change_func = clipeffectseditor.effect_selection_changed
+
     # These provide clues for further module refactoring 
 
 # ---------------------------------- SDL2 consumer
@@ -418,8 +447,9 @@ def create_gui():
     Called at app start to create gui objects and handles for them.
     """
     tlinewidgets.load_icons()
+    kftoolmode.load_icons()
 
-    updater.set_clip_edit_mode_callback = editevent.set_clip_monitor_edit_mode
+    updater.set_clip_edit_mode_callback = modesetting.set_clip_monitor_edit_mode
     updater.load_icons()
 
     # Notebook indexes are differn for 1 and 2 window layouts
@@ -447,8 +477,7 @@ def create_gui():
     # Give undo a reference to uimanager for menuitem state changes
     undo.set_menu_items(gui.editor_window.uimanager)
     
-    # Set button to display sequence in toggled state.
-    gui.sequence_editor_b.set_active(True)
+    updater.display_sequence_in_monitor()
 
 def create_player():
     """
@@ -488,6 +517,7 @@ def init_project_gui():
     gui.bin_list_view.fill_data_model()
     selection = gui.bin_list_view.treeview.get_selection()
     selection.select_path("0")
+    gui.editor_window.bin_info.display_bin_info()
 
     # Display sequences in "Project" tab
     gui.sequence_list_view.fill_data_model()
@@ -530,7 +560,6 @@ def init_editor_state():
 
     gui.media_view_filter_selector.set_pixbuf(editorstate.media_view_filter)
 
-    gui.clip_editor_b.set_sensitive(False)
     gui.editor_window.window.set_title(editorstate.project.name + " - Flowblade")
     gui.editor_window.uimanager.get_widget("/MenuBar/FileMenu/Save").set_sensitive(False)
     gui.editor_window.uimanager.get_widget("/MenuBar/EditMenu/Undo").set_sensitive(False)
@@ -544,6 +573,7 @@ def init_editor_state():
 
     # Clear editors 
     clipeffectseditor.clear_clip()
+    clipeffectseditor.effect_selection_changed() # to get No Clip text
     compositeeditor.clear_compositor()
 
     # Show first pages on notebooks
@@ -553,9 +583,8 @@ def init_editor_state():
     movemodes.clear_selection_values()
 
     # Set initial edit mode
-    gui.editor_window.modes_selector.set_pixbuf(0)
-    editevent.insert_move_mode_pressed()
-
+    modesetting.set_default_edit_mode()
+    
     # Create array needed to update compositors after all edits
     editorstate.current_sequence().restack_compositors()
 
@@ -613,20 +642,27 @@ def open_project(new_project):
     editorstate.transition_length = -1
     editorstate.clear_trim_clip_cache()
     audiomonitoring.init_for_project_load()
-    updater.window_resized()
 
-    gui.editor_window.window.handler_unblock(window_resize_id)
-    gui.editor_window.window.handler_unblock(window_state_id)
     start_autosave()
 
     if new_project.update_media_lengths_on_load == True:
         projectaction.update_media_lengths()
 
-    gui.editor_window.handle_insert_move_mode_button_press()
+    gui.editor_window.set_default_edit_tool()
     editorstate.trim_mode_ripple = False
 
     updater.set_timeline_height()
-        
+
+    gui.editor_window.window.handler_unblock(window_resize_id)
+    gui.editor_window.window.handler_unblock(window_state_id)
+
+    global resize_timeout_id
+    resize_timeout_id = GLib.timeout_add(500, _do_window_resized_update)
+
+def _do_window_resized_update():
+    GObject.source_remove(resize_timeout_id)
+    updater.window_resized()
+    
 def change_current_sequence(index):
     stop_autosave()
     editorstate.project.c_seq = editorstate.project.sequences[index]
@@ -648,6 +684,7 @@ def change_current_sequence(index):
     selection = gui.sequence_list_view.treeview.get_selection()
     selected_index = editorstate.project.sequences.index(editorstate.current_sequence())
     selection.select_path(str(selected_index))
+
     start_autosave()
 
     updater.set_timeline_height()
@@ -763,18 +800,29 @@ def destroy_splash_screen():
     splash_screen.destroy()
     GObject.source_remove(splash_timeout_id)
 
+def show_worflow_info_dialog():
+    editorpersistance.prefs.workflow_dialog_last_version_shown = editorstate.appversion
+    editorpersistance.save()
+    
+    worflow_info_dialog = workflow.WorkflowDialog()
+    return False
+    
 # ------------------------------------------------------- small screens
 def _set_draw_params():
     if editorstate.screen_size_small_width() == True:
-        appconsts.NOTEBOOK_WIDTH = 450
-        editorwindow.MONITOR_AREA_WIDTH = 450
-        editorwindow.MEDIA_MANAGER_WIDTH = 220
+        appconsts.NOTEBOOK_WIDTH = 400
+        editorwindow.MONITOR_AREA_WIDTH = 400
+        editorwindow.MEDIA_MANAGER_WIDTH = 100
         
     if editorstate.screen_size_small_height() == True:
         appconsts.TOP_ROW_HEIGHT = 10
         projectinfogui.PROJECT_INFO_PANEL_HEIGHT = 140
+        tlinewidgets.HEIGHT = 252
+        
+    if editorstate.screen_size_large_height() == True:
+        keyframeeditcanvas.GEOMETRY_EDITOR_HEIGHT = 300
 
-    if editorstate.SCREEN_WIDTH < 1153 and editorstate.SCREEN_HEIGHT < 865:
+    if editorstate.SCREEN_WIDTH < 1153 or editorstate.SCREEN_HEIGHT < 865:
         editorwindow.MONITOR_AREA_WIDTH = 400
         positionbar.BAR_WIDTH = 100
 
@@ -786,7 +834,7 @@ def _set_draw_params():
         sequence.TRACK_HEIGHT_NORMAL = appconsts.TRACK_HEIGHT_NORMAL # track height in canvas and column
         sequence.TRACK_HEIGHT_SMALL = appconsts.TRACK_HEIGHT_SMALL # track height in canvas and column
         tlinewidgets.set_tracks_double_height_consts()
-        
+
 def _too_small_screen_exit():
     global exit_timeout_id
     exit_timeout_id = GObject.timeout_add(200, _show_too_small_info)
@@ -841,6 +889,14 @@ def _shutdown_dialog_callback(dialog, response_id):
 
     # --- APP SHUT DOWN --- #
     print "Exiting app..."
+    # Sep-2018 - SvdB - Stop wave form threads
+    for thread_termination in threading.enumerate():
+        # We only terminate threads with a 'process', as these are launched
+        # by the audiowaveformrenderer
+        try:
+            thread_termination.process.terminate()
+        except:
+            None
 
     # No more auto saving
     stop_autosave()
@@ -855,7 +911,13 @@ def _shutdown_dialog_callback(dialog, response_id):
         editorpersistance.prefs.exit_allocation_window_2 = (alloc.width, alloc.height, pos_x, pos_y)       
     editorpersistance.prefs.app_v_paned_position = gui.editor_window.app_v_paned.get_position()
     editorpersistance.prefs.top_paned_position = gui.editor_window.top_paned.get_position()
-    editorpersistance.prefs.mm_paned_position = gui.editor_window.mm_paned.get_position()
+    try: # This fails if preference for top row layout changed, we just ignore saving these values then.
+        if editorwindow.top_level_project_panel() == True:
+            editorpersistance.prefs.mm_paned_position = 200  # This is not used until user sets preference to not have top level project panel
+        else:
+            editorpersistance.prefs.mm_paned_position = gui.editor_window.mm_paned.get_position()
+    except: 
+        pass
     editorpersistance.save()
 
     # Block reconnecting consumer before setting window not visible
