@@ -113,10 +113,10 @@ def init(profile):
 
     global CONTROL_SLOT_H, METER_SLOT_H, METER_LIGHTS, METER_HEIGHT
     if editorstate.screen_size_small_height() == True:
-        if editorstate.SCREEN_HEIGHT > 898:
-            METER_SLOT_H = 400
+        if editorstate.SCREEN_HEIGHT > 902:
+            METER_SLOT_H = 300
             CONTROL_SLOT_H = 240
-            METER_LIGHTS = 123
+            METER_LIGHTS = 100
             METER_HEIGHT = METER_LIGHTS * DASH_INK + (METER_LIGHTS - 1) * DASH_SKIP
         else:
             METER_SLOT_H = 275
@@ -391,7 +391,10 @@ class MetersArea:
     def _draw(self, event, cr, allocation):
         x, y, w, h = allocation
 
-        cr.set_source_rgb(*METER_BG_COLOR)
+        if editorpersistance.prefs.theme == appconsts.LIGHT_THEME:
+            cr.set_source_rgb(*METER_BG_COLOR)
+        else:
+            cr.set_source_rgb(0.0, 0.0, 0.0)
         cr.rectangle(0, 0, w, h)
         cr.fill()
 
@@ -651,7 +654,11 @@ class MasterVolumeMeter:
     def _draw(self, event, cr, allocation):
         x, y, w, h = allocation
 
-        cr.set_source_rgb(*METER_BG_COLOR)
+        if editorpersistance.prefs.theme == appconsts.LIGHT_THEME:
+            cr.set_source_rgb(*METER_BG_COLOR)
+        else:
+            cr.set_source_rgb(0.0, 0.0, 0.0)
+        cr.fill_preserve()
         cr.rectangle(0, 0, w, h)
         cr.fill()
 
