@@ -23,17 +23,14 @@ Modules handles creating and caching audio waveform images for clips.
 """
 
 import locale
-import math
-import md5
 import mlt
 import os
 import pickle
-import struct
 import subprocess
 import sys
 import threading
 
-from gi.repository import Gtk, Gdk
+from gi.repository import Gdk
 
 import appconsts
 import editorpersistance
@@ -42,6 +39,7 @@ import mltenv
 import mltprofiles
 import mlttransitions
 import mltfilters
+import processutils
 import renderconsumer
 import respaths
 import translations
@@ -136,10 +134,11 @@ class AudioRenderLaunchThread(threading.Thread):
     def run(self):
         # Launch render process and wait for it to end
         FLOG = open(utils.get_hidden_user_dir_path() + "log_audio_levels_render", 'w')
-        process = subprocess.Popen([sys.executable, respaths.LAUNCH_DIR + "flowbladeaudiorender", \
+        # Sep-2018 - SvdB - Added self. to be able to access the thread through 'process'
+        self.process = subprocess.Popen([sys.executable, respaths.LAUNCH_DIR + "flowbladeaudiorender", \
                   self.rendered_media, self.profile_desc, respaths.ROOT_PATH], \
                   stdin=FLOG, stdout=FLOG, stderr=FLOG)
-        process.wait()
+        self.process.wait()
         
         Gdk.threads_enter()
         updater.repaint_tline()
@@ -187,7 +186,8 @@ def main():
     mlttransitions.init_module()
 
     repo = mlt.Factory().init()
-
+    processutils.prepare_mlt_repo(repo)
+    
     # Set numeric locale to use "." as radix, MLT initilizes this to OS locale and this causes bugs 
     locale.setlocale(locale.LC_NUMERIC, 'C')
 
