@@ -48,7 +48,9 @@ from editorstate import current_sequence
 from editorstate import get_track
 from editorstate import PROJECT
 from editorstate import PLAYER
+import kftoolmode
 import mlttransitions
+import modesetting
 import movemodes
 import syncsplitevent
 import tlinewidgets
@@ -68,10 +70,11 @@ def display_clip_menu(y, event, frame):
     if clip_index == -1:
         return False
     # Can't do anything to clips in locked tracks
-    if editevent.track_lock_check_and_user_info(track, display_clip_menu, "clip context menu"):
+    if dialogutils.track_lock_check_and_user_info(track):
         return False
     
     # Display popup
+    gui.tline_canvas.drag_on = False
     pressed_clip = track.clips[clip_index]
     if pressed_clip.is_blanck_clip == False:
         movemodes.select_clip(track.id, clip_index)
@@ -619,7 +622,13 @@ def _delete_all_clip_markers(data):
     clip.markers = []
     updater.repaint_tline()
 
-
+def _volume_keyframes(data):
+    clip, track, item_id, item_data = data
+    modesetting.kftool_mode_from_popup_menu(clip, track, kftoolmode.VOLUME_KF_EDIT)
+    
+def _brightness_keyframes(data):
+    clip, track, item_id, item_data = data
+    modesetting.kftool_mode_from_popup_menu(clip, track, kftoolmode.BRIGHTNESS_KF_EDIT)
 
 # Functions to handle popup menu selections for strings 
 # set as activation messages in guicomponents.py
@@ -663,4 +672,6 @@ POPUP_HANDLERS = {"set_master":syncsplitevent.init_select_master_clip,
                   "add_clip_marker":_add_clip_marker,
                   "go_to_clip_marker":_go_to_clip_marker,
                   "delete_clip_marker":_delete_clip_marker,
-                  "deleteall_clip_markers":_delete_all_clip_markers}
+                  "deleteall_clip_markers":_delete_all_clip_markers,
+                  "volumekf":_volume_keyframes,
+                  "brightnesskf":_brightness_keyframes}
