@@ -22,7 +22,6 @@
 Module handles Compositors edit panel.
 """
 
-import cairo
 import copy
 from gi.repository import Gtk
 import pickle
@@ -35,7 +34,6 @@ import gui
 import guicomponents
 import guiutils
 import edit
-import editorstate
 from editorstate import current_sequence
 import editorpersistance
 import keyframeeditor
@@ -43,7 +41,6 @@ import mlttransitions
 import propertyeditorbuilder
 import propertyedit
 import propertyparse
-import respaths
 import utils
 
 COMPOSITOR_PANEL_LEFT_WIDTH = 160
@@ -62,25 +59,11 @@ def create_widgets():
     """
     Widgets for editing compositing properties.
     """
-    # Left side
     widgets.compositor_info = guicomponents.CompositorInfoPanel()
-    widgets.fade_in_b = Gtk.Button(_("Add Fade In"))
-    widgets.fade_in_b.connect("clicked", lambda w,e: _add_fade_in_pressed(), None)
-    widgets.fade_out_b = Gtk.Button(_("Add Fade Out"))
-    widgets.fade_out_b.connect("clicked", lambda w,e: _add_fade_out_pressed(), None)
-
-    widgets.fade_in_spin = Gtk.SpinButton.new_with_range(0, 150, 1)
-    widgets.fade_in_spin.set_value(10)
+    widgets.hamburger_launcher = guicomponents.HamburgerPressLaunch(_hamburger_launch_pressed)
+    guiutils.set_margins(widgets.hamburger_launcher.widget, 4, 6, 6, 0)
     
-    widgets.fade_out_spin = Gtk.SpinButton.new_with_range(0, 150, 1)
-    widgets.fade_out_spin.set_value(10)
-    
-    widgets.delete_b = Gtk.Button(_("Delete"))
-    widgets.delete_b.connect("clicked", lambda w,e: _delete_compositor_pressed(), None)
-    widgets.reset_b = Gtk.Button(_("Reset"))
-    widgets.reset_b.connect("clicked", lambda w,e: _reset_compositor_pressed(), None)
-    
-    # Right side
+    # Edit area
     widgets.empty_label = Gtk.Label(label=_("No Compositor"))
     widgets.value_edit_box = Gtk.VBox()
     widgets.value_edit_box.pack_start(widgets.empty_label, True, True, 0)
@@ -90,29 +73,17 @@ def create_widgets():
 
 def get_compositor_clip_panel():
     create_widgets()
-    small = (editorstate.SCREEN_HEIGHT < 1000)
     
-    compositor_vbox = Gtk.VBox(False, 2)
-    compositor_vbox.pack_start(widgets.compositor_info, False, False, 0)
-    if not small:
-        compositor_vbox.pack_start(guiutils.get_pad_label(5, 24), False, False, 0)
-    compositor_vbox.pack_start(widgets.fade_in_b, False, False, 0)
-    compositor_vbox.pack_start(widgets.fade_in_spin, False, False, 0)
-    if not small:
-        compositor_vbox.pack_start(guiutils.get_pad_label(5, 12), False, False, 0)
-    compositor_vbox.pack_start(widgets.fade_out_b, False, False, 0)
-    compositor_vbox.pack_start(widgets.fade_out_spin, False, False, 0)
-    if not small:
-        compositor_vbox.pack_start(guiutils.get_pad_label(5, 24), False, False, 0)
-    compositor_vbox.pack_start(Gtk.Label(), True, True, 0)
-    compositor_vbox.pack_start(widgets.reset_b, False, False, 0)
-    if not small:
-        compositor_vbox.pack_start(widgets.delete_b, False, False, 0)
-        compositor_vbox.pack_start(guiutils.get_pad_label(5, 3), False, False, 0)
-
+    # Action row
+    action_row = Gtk.HBox(False, 2)
+    action_row.pack_start(widgets.hamburger_launcher.widget, False, False, 0)
+    action_row.pack_start(Gtk.Label(), True, True, 0)
+    action_row.pack_start(widgets.compositor_info, False, False, 0)
+    action_row.pack_start(Gtk.Label(), True, True, 0)
+    
     set_enabled(False)
     
-    return compositor_vbox
+    return action_row
     
 def set_compositor(new_compositor):
     """
@@ -141,22 +112,11 @@ def clear_compositor():
 def set_enabled(value):
     widgets.empty_label.set_sensitive(value)
     widgets.compositor_info.set_enabled(value)
-    widgets.delete_b.set_sensitive(value)
-    widgets.reset_b.set_sensitive(value)
-
-    if compositor == None or (compositor.transition.info.auto_fade_compositor == False \
-        and mlttransitions.is_blender(compositor.transition.info.name) == False):
-        widgets.fade_in_b.set_sensitive(value)
-        widgets.fade_out_b.set_sensitive(value)
-        widgets.fade_in_spin.set_sensitive(value)
-        widgets.fade_out_spin.set_sensitive(value)
-    else: # Autofade compositors or blenders don't use these buttons
-        widgets.fade_in_b.set_sensitive(False)
-        widgets.fade_out_b.set_sensitive(False)
-        widgets.fade_in_spin.set_sensitive(False)
-        widgets.fade_out_spin.set_sensitive(False)
+    widgets.hamburger_launcher.set_sensitive(value)
 
 def maybe_clear_editor(killed_compositor):
+    if compositor == None:
+        return
     if killed_compositor.destroy_id == compositor.destroy_id:
         clear_compositor()
 
@@ -197,13 +157,30 @@ def _display_compositor_edit_box():
     # Case: Empty edit frame
     global compositor
     if compositor == None:
-        widgets.empty_label = Gtk.Label(label=_("No Compositor"))
-        vbox.pack_start(widgets.empty_label, True, True, 0)
+        #widgets.empty_label = Gtk.Label(label=_("No Compositor"))
 
-        vbox.pack_start(Gtk.Label(), True, True, 0)  
+        filler = Gtk.EventBox()
+        filler.add(Gtk.Label())
+        vbox.pack_start(filler, True, True, 0)
+        
+        info = Gtk.Label(label=_("No Compositor"))
+        info.set_sensitive(False)
+        filler = Gtk.EventBox()
+        filler.add(info)
+        vbox.pack_start(filler, False, False, 0)
+        
+        filler = Gtk.EventBox()
+        filler.add(Gtk.Label())
+        vbox.pack_start(filler, True, True, 0)
         vbox.show_all()
-        widgets.value_edit_box = vbox
-        widgets.value_edit_frame.add(vbox)
+
+        scroll_window = Gtk.ScrolledWindow()
+        scroll_window.add_with_viewport(vbox)
+        scroll_window.set_policy(Gtk.PolicyType.AUTOMATIC, Gtk.PolicyType.AUTOMATIC)
+        scroll_window.show_all()
+
+        widgets.value_edit_box = scroll_window
+        widgets.value_edit_frame.add(scroll_window)
         return 
 
     # Case: Filled frame
@@ -227,10 +204,37 @@ def _display_compositor_edit_box():
     vbox.pack_start(target_row, False, False, 0)
     vbox.pack_start(guicomponents.EditorSeparator().widget, False, False, 0)
 
+    # Fade buttons
+    compositor_info = guicomponents.CompositorInfoPanel()
+    fade_in_b = Gtk.Button(_("Add Fade In"))
+    fade_in_b.connect("clicked", lambda w,e: _add_fade_in_pressed(), None)
+
+    fade_out_b = Gtk.Button(_("Add Fade Out"))
+    fade_out_b.connect("clicked", lambda w,e: _add_fade_out_pressed(), None)
+
+    widgets.fade_in_spin = Gtk.SpinButton.new_with_range(0, 150, 1)
+    widgets.fade_in_spin.set_value(10)
+    
+    widgets.fade_out_spin = Gtk.SpinButton.new_with_range(0, 150, 1)
+    widgets.fade_out_spin.set_value(10)
+    
+    fades_row = Gtk.HBox()
+    fades_row.pack_start(guiutils.get_pad_label(5, 3), False, False, 0)
+    fades_row.pack_start(fade_in_b, False, False, 0)
+    fades_row.pack_start(widgets.fade_in_spin, False, False, 0)
+    fades_row.pack_start(fade_out_b, False, False, 0)
+    fades_row.pack_start(widgets.fade_out_spin, False, False, 0)
+    fades_row.pack_start(Gtk.Label(), True, True, 0)
+    
+    if _compositor_uses_fade_buttons(compositor) == True:
+        vbox.pack_start(fades_row, False, False, 0)
+        vbox.pack_start(guicomponents.EditorSeparator().widget, False, False, 0)
+    
     # Transition editors
     t_editable_properties = propertyedit.get_transition_editable_properties(compositor)
     for ep in t_editable_properties:
         editor_row = propertyeditorbuilder.get_editor_row(ep)
+            
         if editor_row != None: # Some properties don't have editors
             vbox.pack_start(editor_row, False, False, 0)
             vbox.pack_start(guicomponents.EditorSeparator().widget, False, False, 0)
@@ -259,11 +263,6 @@ def _display_compositor_edit_box():
         vbox.pack_start(editor_row, False, False, 0)
         vbox.pack_start(guicomponents.EditorSeparator().widget, False, False, 0)
 
-    hamburger_launcher_surface = cairo.ImageSurface.create_from_png(respaths.IMAGE_PATH + "hamburger_big.png")
-    hamburger_launcher = guicomponents.PressLaunch(_hamburger_launch_pressed, hamburger_launcher_surface, 24, 24)
-    sl_row = guiutils.get_left_justified_box([hamburger_launcher.widget])
-    vbox.pack_start(sl_row, False, False, 0)
-        
     vbox.pack_start(Gtk.Label(), True, True, 0)  
     vbox.show_all()
 
@@ -288,10 +287,34 @@ def display_kfeditors_tline_frame(frame):
     for kf_widget in keyframe_editor_widgets:
         kf_widget.display_tline_frame(frame)
 
+def update_kfeditors_sliders(frame):
+    for kf_widget in keyframe_editor_widgets:
+        kf_widget.update_slider_value_display(frame)
+        
 def update_kfeditors_positions():
     for kf_widget in keyframe_editor_widgets:
         kf_widget.update_clip_pos()
 
+
+def _compositor_uses_fade_buttons(compositor):
+    # we hard coded compositors using fade buttons here because adding data in compostors.xml may have had some backwards compatiblity issues.
+    if compositor.transition.info.name  == "##opacity":
+        return True
+    elif compositor.transition.info.name  == "##pict_in_pict":
+        return True
+    elif compositor.transition.info.name  == "##affine":
+        return True
+    elif compositor.transition.info.name  == "##opacity_kf":
+        return True
+    elif compositor.transition.info.name  == "##region":
+        return True
+    elif compositor.transition.info.name  == "##affineblend":
+        return True
+    elif compositor.transition.info.name  == "##blend":
+        return True
+        
+        
+    return False
 # ----------------------------------------------------------- hamburger menu
 def _hamburger_launch_pressed(widget, event):
     guicomponents.get_compositor_editor_hamburger_menu(event, _compositor_hamburger_item_activated)
@@ -307,7 +330,9 @@ def _compositor_hamburger_item_activated(widget, msg):
         _reset_compositor_pressed()
     elif msg == "delete":
         _delete_compositor_pressed()
-
+    elif msg == "close":
+        clear_compositor()
+        
 def _save_compositor_values_dialog_callback(dialog, response_id):
     if response_id == Gtk.ResponseType.ACCEPT:
         save_path = dialog.get_filenames()[0]
