@@ -72,8 +72,8 @@ def new_project_dialog(callback):
     profiles_vbox = guiutils.get_vbox([profile_select,profile_info_box], False)
     profiles_frame = panels.get_named_frame(_("Profile"), profiles_vbox)
 
-    tracks_select = guicomponents.TracksNumbersSelect(5, 4)
-    
+    tracks_select = guicomponents.TracksNumbersSelect(appconsts.INIT_V_TRACKS, appconsts.INIT_A_TRACKS)
+
     tracks_vbox = guiutils.get_vbox([tracks_select.widget], False)
 
     tracks_frame = panels.get_named_frame(_("Tracks"), tracks_vbox)
@@ -282,7 +282,7 @@ def save_project_as_dialog(callback, current_name, open_dir, parent=None):
                                    (_("Cancel").encode('utf-8'), Gtk.ResponseType.CANCEL,
                                     _("Save").encode('utf-8'), Gtk.ResponseType.ACCEPT))
     dialog.set_action(Gtk.FileChooserAction.SAVE)
-    dialog.set_current_name(current_name)
+    dialog.set_current_name(current_name.encode('utf-8'))
     dialog.set_do_overwrite_confirmation(True)
     if open_dir != None:
         dialog.set_current_folder(open_dir)
@@ -349,7 +349,7 @@ def _export_file_name_dialog(callback, project_name, dialog_title):
                                    _("Export").encode('utf-8'), Gtk.ResponseType.ACCEPT))
     dialog.set_action(Gtk.FileChooserAction.SAVE)
     project_name = project_name.strip(".flb")
-    dialog.set_current_name(project_name + ".xml")
+    dialog.set_current_name(project_name.encode('utf-8') + ".xml")
     dialog.set_do_overwrite_confirmation(True)
 
     dialog.set_select_multiple(False)
@@ -488,8 +488,8 @@ def about_dialog(parent_window):
     # Application tab
     img = Gtk.Image.new_from_file(respaths.IMAGE_PATH + "flowbladeappicon.png")
     flow_label = Gtk.Label(label="Flowblade Movie Editor")
-    ver_label = Gtk.Label(label="1.16.0")
-    janne_label = Gtk.Label(label="Copyright 2018 Janne Liljeblad and contributors")
+    ver_label = Gtk.Label(label="2.0.0")
+    janne_label = Gtk.Label(label="Copyright 2019 Janne Liljeblad and contributors")
     page_label = Gtk.Label(label=_("Project page:") + " " + "<a href=\"https://github.com/jliljebl/flowblade\">https://github.com/jliljebl/flowblade</a>")
     page_label.set_use_markup(True)
     flow_label.modify_font(Pango.FontDescription("sans bold 14"))
@@ -939,15 +939,16 @@ def _autosaves_delete_unselected(autosaves, autosaves_view):
     autosaves.append(selected_autosave)
     autosaves_view.fill_data_model(autosaves)
 
-def tracks_count_change_dialog(callback):
+def tracks_count_change_dialog(callback, v_tracks, a_tracks):
     dialog = Gtk.Dialog(_("Change Sequence Tracks Count"),  gui.editor_window.window,
                         Gtk.DialogFlags.MODAL | Gtk.DialogFlags.DESTROY_WITH_PARENT,
                         (_("Cancel").encode('utf-8'), Gtk.ResponseType.REJECT,
                         _("Change Tracks").encode('utf-8'), Gtk.ResponseType.ACCEPT))
-    
-    tracks_select = guicomponents.TracksNumbersSelect(5, 4)
-        
-    info_text = _("Please note:\n") + \
+
+    tracks_select = guicomponents.TracksNumbersSelect(v_tracks, a_tracks)
+
+    info_text = _("Please note:\n\n") + \
+                u"\u2022" + _(" When reducing the number of tracks the top Video track and/or bottom Audio track will be removed\n") + \
                 u"\u2022" + _(" It is recommended that you save Project before completing this operation\n") + \
                 u"\u2022" + _(" There is no Undo for this operation\n") + \
                 u"\u2022" + _(" Current Undo Stack will be destroyed\n") + \
@@ -1007,9 +1008,9 @@ def new_sequence_dialog(callback, default_name):
     name_select = panels.get_two_column_box(Gtk.Label(label=_("Sequence Name:")),
                                                name_entry,
                                                250)
-   
-    tracks_select = guicomponents.TracksNumbersSelect(5, 4)
-    
+
+    tracks_select = guicomponents.TracksNumbersSelect(appconsts.INIT_V_TRACKS, appconsts.INIT_A_TRACKS)
+
     open_check = Gtk.CheckButton()
     open_check.set_active(True)
     open_label = Gtk.Label(label=_("Open For Editing:"))
@@ -1262,7 +1263,7 @@ def export_edl_dialog(callback, parent_window, project_name):
                                    _("Export").encode('utf-8'), Gtk.ResponseType.ACCEPT))
     dialog.set_action(Gtk.FileChooserAction.SAVE)
     project_name = project_name.rstrip(".flb")
-    dialog.set_current_name(project_name + ".edl")
+    dialog.set_current_name(project_name.encode('utf-8') + ".edl")
     dialog.set_do_overwrite_confirmation(True)
 
     dialog.set_select_multiple(False)
@@ -1440,6 +1441,7 @@ def _get_dynamic_kb_shortcuts_panel(xml_file):
     tline_vbox.pack_start(_get_kb_row(_("Alt + I"), _("Go To Mark In")), False, False, 0)
     tline_vbox.pack_start(_get_kb_row(_("Alt + O"), _("Go To Mark Out")), False, False, 0)
     tline_vbox.pack_start(_get_dynamic_kb_row(root_node, "cut"), False, False, 0)
+    tline_vbox.pack_start(_get_dynamic_kb_row(root_node, "cut_all"), False, False, 0)
     tline_vbox.pack_start(_get_kb_row(_("DELETE"),  _("Splice Out")), False, False, 0)
     tline_vbox.pack_start(_get_dynamic_kb_row(root_node, "insert"), False, False, 0)
     tline_vbox.pack_start(_get_dynamic_kb_row(root_node, "append"), False, False, 0)
@@ -1483,7 +1485,7 @@ def _get_dynamic_kb_shortcuts_panel(xml_file):
     tools_vbox.pack_start(_get_dynamic_kb_row(root_node, "edit_mode_spacer"), False, False, 0)
     tools_vbox.pack_start(_get_dynamic_kb_row(root_node, "edit_mode_box"), False, False, 0)
     tools_vbox.pack_start(_get_kb_row(_("Keypad 1-7"), _("Same as 1-7")), False, False, 0)
-    tools_vbox.pack_start(_get_kb_row(_("R"), _("Trim Tool Ripple Mode On/Off")), False, False, 0)
+    tools_vbox.pack_start(_get_kb_row(_("R"), _("Toggle Trim / Ripple Trim Tools")), False, False, 0)
     tools = guiutils.get_named_frame(_("Tools"), tools_vbox)
 
     geom_vbox = Gtk.VBox()
@@ -1492,7 +1494,11 @@ def _get_dynamic_kb_shortcuts_panel(xml_file):
     geom_vbox.pack_start(_get_kb_row(_("Up Arrow"), _("Move Source Video Up 1px")), False, False, 0)
     geom_vbox.pack_start(_get_kb_row(_("Down Arrow"), _("Move Source Video Down 1px")), False, False, 0)
     geom_vbox.pack_start(_get_kb_row(_("Control + Arrow"), _("Move Source Video 10px")), False, False, 0)
-    geom_vbox.pack_start(_get_kb_row(_("Control + Mouse Drag"), _("Keep Aspect Ratio in Affine Blend scaling")), False, False, 0) 
+    geom_vbox.pack_start(_get_kb_row(_("Control + Mouse Drag"), _("Keep Aspect Ratio in Affine Blend scaling")), False, False, 0)
+    geom_vbox.pack_start(_get_kb_row(_("Shift + Left Arrow "), _("Scale Down")), False, False, 0)
+    geom_vbox.pack_start(_get_kb_row(_("Shift + Right Arrow"), _("Scale Up")), False, False, 0)
+    geom_vbox.pack_start(_get_kb_row(_("Shift + Control + Left Arrow "), _("Scale Down More")), False, False, 0)
+    geom_vbox.pack_start(_get_kb_row(_("Shift + Control + Right Arrow"), _("Scale Up More")), False, False, 0)
     geom_vbox.pack_start(_get_kb_row(_("Shift"), _("Snap to X or Y of drag start point")), False, False, 0)
     geom = guiutils.get_named_frame(_("Geometry Editor"), geom_vbox)
 
@@ -1880,4 +1886,11 @@ def tline_audio_sync_dialog(callback, data):
     dialog.connect('response', callback, data)
     dialog.show_all()
 
+def no_audio_dialog(track):
+    dialogutils.warning_message(_("Can't put an audio clip on a video track."), 
+                            _("Track ")+ utils.get_track_name(track, editorstate.current_sequence()) + _(" is a video track and can't display audio only material."),
+                            gui.editor_window.window)
 
+
+        
+        
