@@ -43,7 +43,9 @@ SLIDE_TRIM_NO_EDIT = 9
 MULTI_MOVE = 10
 CLIP_END_DRAG = 11
 SELECT_TLINE_SYNC_CLIP = 12
-
+CUT = 13
+KF_TOOL = 14
+MULTI_TRIM = 15
 
 # SDL version (Not used currently)
 SDL_1 = 1
@@ -61,10 +63,10 @@ edit_mode = INSERT_MOVE
 # Compositor autofollow state. If true when edit is performed, all compositors are auto resynced on first do, redo and undo actions.
 auto_follow = False
 
-# Trim tool ripple mode is expressed as a flag
+# Ripple Trim tool is ONE_ROLL_TRIM mode + True on this flag
 trim_mode_ripple = False
 
-# Ovewrite tool box mode is expressed as a flag
+# Box tool OVERWRITE_MOVE tool mode + True on this flag
 overwrite_mode_box = False
 
 # Media files view filter for selecting displayed media objects in bin
@@ -76,6 +78,9 @@ _monitor_media_file = None
 # Flag for timeline/clip display in monitor
 _timeline_displayed = True
 
+# Used to ignore drag and release events when press doesn't start an action that can/should handle those events.
+timeline_mouse_disabled = False
+
 # Timeline current frame is saved here while clip is being displayed in monitor
 # and PLAYER() current frame is not timeline frame 
 tline_shadow_frame = -1
@@ -93,7 +98,7 @@ SCREEN_WIDTH = -1
 # Runtime environment data
 gtk_version = None
 mlt_version = None
-appversion = "0.10"
+appversion = "2.0.0"
 RUNNING_FROM_INSTALLATION = 0
 RUNNING_FROM_DEV_VERSION = 1
 app_running_from = RUNNING_FROM_INSTALLATION
@@ -105,9 +110,11 @@ use_xdg = False
 # Cursor position and sensitivity
 cursor_on_tline = False
 cursor_is_tline_sensitive = True
+last_mouse_x = -1 # This is only used by multitrimmode.py 
+last_mouse_y = -1 # This is only used by multitrimmode.py 
 
 # Flag for running JACK audio server. If this is on when SDLConsumer created in mltplayer.py
-# jack rack filter will bw taached to it
+# jack rack filter will bw attached to it
 # NOT USED CURRENTLY.
 attach_jackrack = False
 
@@ -165,7 +172,7 @@ def PROJECT():
     
 def PLAYER():
     return player
-    
+
 def EDIT_MODE():
     return edit_mode
     
@@ -192,7 +199,7 @@ def mlt_version_is_equal_or_greater(test_version):
     
     return False
 
-def mlt_version_is_equal_or_greater_correct(test_version):
+def mlt_version_is_greater_correct(test_version):
     runtime_ver = mlt_version.split(".")
     test_ver = test_version.split(".")
     
@@ -206,6 +213,21 @@ def mlt_version_is_equal_or_greater_correct(test_version):
                 return True
     
     return False
+
+def runtime_version_greater_then_test_version(test_version, runtime_version):
+    runtime_ver = runtime_version.split(".")
+    test_ver = test_version.split(".")
+    
+    if runtime_ver[0] > test_ver[0]:
+        return True
+    elif runtime_ver[0] == test_ver[0]:
+        if runtime_ver[1] > test_ver[1]:
+            return True
+        elif runtime_ver[1] == test_ver[1]:
+            if  runtime_ver[2] >  test_ver[2]:
+                return True
+    
+    return False
     
 def set_copy_paste_objects(objs):
     global _copy_paste_objects
@@ -224,7 +246,7 @@ def screen_size_small_height():
         return False
 
 def screen_size_small_width():
-    if SCREEN_WIDTH < 1368:
+    if SCREEN_WIDTH < 1420:
         return True
     else:
         return False
@@ -235,12 +257,12 @@ def screen_size_small():
     
     return False
 
-def screen_size_small_height():
-    if SCREEN_HEIGHT < 898:
+def screen_size_large_height():
+    if SCREEN_HEIGHT > 1048:
         return True
     else:
         return False
-
+        
 def get_cached_trim_clip(path):
     try:
         return _trim_clips_cache[path]
@@ -254,6 +276,14 @@ def clear_trim_clip_cache():
     global _trim_clips_cache
     _trim_clips_cache = {}
 
+
+# Called from tline "motion_notify_event" when drag is not on.
+# This is only used by multitrimmode.py to have data to enter trims with keyboard correctly
+def set_mouse_current_non_drag_pos(x, y):
+    global last_mouse_x, last_mouse_y
+    last_mouse_x = x
+    last_mouse_y = y
+    
 """
 def get_sdl_version(): # This ain't true anymore, 6.6.0 has both available
     if mlt_version_is_equal_or_greater_correct("6.4.2") == True:
