@@ -26,17 +26,15 @@ import math
 
 from gi.repository import Gtk
 
+import appconsts
 import cairo
 import cairoarea
 import editorpersistance
-from editorstate import PLAYER
-import gui
 import guiutils
 import guicomponents
 import glassbuttons
 import lutfilter
 import respaths
-import viewgeom
 import translations
 
 SHADOW = 0
@@ -719,7 +717,7 @@ class BoxEditor:
     def draw_box(self, cr, allocation):
         x, y, w, h = allocation
 
-        if editorpersistance.prefs.dark_theme == False:
+        if editorpersistance.prefs.theme == appconsts.LIGHT_THEME:
             cr.set_source_rgb(*BOX_BG_COLOR )
             cr.rectangle(0, 0, self.pix_size + 1, self.pix_size + 1)
             cr.fill()
@@ -873,7 +871,7 @@ class CurvesBoxEditor(BoxEditor):
         self.last_point = None
         self.edit_on = False
 
-        if editorpersistance.prefs.dark_theme == True:
+        if editorpersistance.prefs.theme != appconsts.LIGHT_THEME:
             BOX_LINE_COLOR = (0.8, 0.8, 0.8)
             CURVE_COLOR = (0.8, 0.8, 0.8)
             self.curve_color = CURVE_COLOR
