@@ -21,8 +21,7 @@
 import cairo
 import math
 
-from gi.repository import Gtk
-
+import appconsts
 import cairoarea
 import editorpersistance
 import gui
@@ -50,11 +49,12 @@ CORNER_DIVIDER = 5
 MB_BUTTONS_WIDTH = 317
 MB_BUTTONS_HEIGHT = 30
 MB_BUTTON_HEIGHT = 22
-MB_BUTTON_WIDTH = 35
+MB_BUTTON_WIDTH = 30
 MB_BUTTON_Y = 4
 MB_BUTTON_IMAGE_Y = 6
 
 GMIC_BUTTONS_WIDTH = 250
+NATRON_BUTTONS_WIDTH = 100
 
 M_PI = math.pi
 
@@ -64,8 +64,7 @@ NO_HIT = -1
 DEFAULT_FOCUS_GROUP = "default_focus_group"
 focus_groups = {DEFAULT_FOCUS_GROUP:[]}
 
-#FLAT_COLOR_LIGHT = (0.9, 0.9, 0.9)
-#FLAT_COLOR_DARK = (0.25, 0.25, 0.25)
+
 
 class AbstractGlassButtons:
 
@@ -104,7 +103,7 @@ class AbstractGlassButtons:
         
         # Dark theme comes with flat buttons
         self.dark_theme = False
-        if editorpersistance.prefs.dark_theme == True:
+        if editorpersistance.prefs.theme != appconsts.LIGHT_THEME:
             self.glass_style = False
             self.dark_theme = True
 
@@ -301,12 +300,12 @@ class PlayerButtons(AbstractGlassButtons):
             self.icons = [prev_icon, next_icon, play_pause_icon,
                           mark_in_icon, mark_out_icon, 
                           marks_clear_icon, to_mark_in_icon, to_mark_out_icon]
-            self.image_x = [8, 10, 8, 6, 14, 5, 10, 9]
+            self.image_x = [5, 7, 5, 3, 11, 2, 7, 6]
         else:
             self.icons = [prev_icon, next_icon, play_icon, stop_icon, 
                           mark_in_icon, mark_out_icon, 
                           marks_clear_icon, to_mark_in_icon, to_mark_out_icon]
-            self.image_x = [8, 10, 13, 13, 6, 14, 5, 10, 9]
+            self.image_x = [5, 7, 10, 10, 3, 11, 2, 7, 6]
 
         for i in range(0, len(self.icons)):
             self.image_y.append(MB_BUTTON_IMAGE_Y)
@@ -445,6 +444,8 @@ class GmicButtons(AbstractGlassButtons):
         self.button_x = mid_x - (buttons_width / 2)
         self._draw_buttons(cr, w, h)
 
+
+
 class GlassButtonsGroup(AbstractGlassButtons):
 
     def __init__(self, button_width, button_height, button_y, image_x_default, image_y_default, focus_group=DEFAULT_FOCUS_GROUP):
@@ -489,6 +490,7 @@ class GlassButtonsGroup(AbstractGlassButtons):
         self.widget.queue_draw()
 
 
+
 class GlassButtonsToggleGroup(GlassButtonsGroup):    
     def set_pressed_button(self, pressed_button_index, fire_clicked_cb=False):
         self.pressed_button = pressed_button_index
@@ -516,6 +518,34 @@ class GlassButtonsToggleGroup(GlassButtonsGroup):
         pass
 
 
+
+class TooltipRunner:
+    
+    def __init__(self, glassbuttons, tooltips):
+        self.glassbuttons = glassbuttons
+        self.tooltips = tooltips
+        
+        self.glassbuttons.widget.set_has_tooltip(True)
+        self.glassbuttons.widget.connect("query-tooltip", self.tooltip_query)
+        self.glassbuttons.tooltip_runner = self
+        
+        self.last_hit_code = NO_HIT
+        
+    def tooltip_query(self, widget, x, y, keyboard_tooltip, tooltip):
+        hit_code = self.glassbuttons._get_hit_code(x, y)
+        if hit_code == NO_HIT:
+            return False
+        
+        # This is needed to get better position for tooltips when tooltips have significantly different amount of text displayed 
+        if hit_code != self.last_hit_code:
+            self.last_hit_code = hit_code
+            self.glassbuttons.widget.trigger_tooltip_query()
+            return False
+        
+        tooltip.set_markup(self.tooltips[hit_code])
+        return True
+        
+
 def focus_group_has_focus(focus_group):
     group = focus_groups[focus_group]
     for widget in group:
