@@ -26,7 +26,9 @@ from gi.repository import Gtk, Gdk
 
 import pickle
 
+import appconsts
 import editorpersistance
+import respaths
 import utils
 
 # Editor window
@@ -38,6 +40,7 @@ editmenu = None
 # Project data lists
 media_list_view = None
 bin_list_view = None
+bin_panel = None
 sequence_list_view = None
 effect_stack_list_view = None
 
@@ -51,7 +54,7 @@ render_out_folder = None
 
 # Media tab
 media_view_filter_selector = None
-proxy_button = None
+#proxy_button = None
 
 # Monitor
 pos_bar = None
@@ -68,12 +71,10 @@ tline_left_corner = None
 big_tc = None
 
 monitor_widget = None
-
+monitor_switch = None
 # indexes match editmode values in editorstate.py
 notebook_buttons = None
 
-play_b = None
-clip_editor_b = None
 sequence_editor_b = None
 
 
@@ -83,11 +84,12 @@ _UBUNTU_COLORS = ((0.949020, 0.945098, 0.941176),  (0.172, 0.172, 0.172), (0.941
 _GNOME_COLORS = ((0.929412, 0.929412, 0.929412), (0.172, 0.172, 0.172), (0.28627451, 0.560784314, 0.843137255), (0.192, 0.361, 0.608), "Gnome")
 _MINT_COLORS = ((0.839215686, 0.839215686, 0.839215686), (0.172, 0.172, 0.172), (0.556862745, 0.678431373, 0.439215686), (0.556862745, 0.678431373, 0.439215686), "Linux Mint")
 _ARC_COLORS = ((0.960784, 0.964706, 0.968627), (0.266667, 0.282353, 0.321569), (0.321568627, 0.580392157, 0.88627451), (0.321568627, 0.580392157, 0.88627451), "Arc (theme)")
+_FLOWBLADE_COLORS = ((0.960784, 0.964706, 0.968627), (0.266667, 0.282353, 0.321569), (0.1, 0.31, 0.58), (0.1, 0.31, 0.58), "Flowblade Theme")
 
 
-_THEME_COLORS = (_UBUNTU_COLORS, _GNOME_COLORS, _MINT_COLORS, _ARC_COLORS)
+_THEME_COLORS = (_UBUNTU_COLORS, _GNOME_COLORS, _MINT_COLORS, _ARC_COLORS, _FLOWBLADE_COLORS)
 
-_CURRENT_THEME_COLORS_FILE = "currentcolors.data"
+_CURRENT_THEME_COLORS_FILE = "currentcolors.data" # Used to communicate theme colors to tools like gmic.py running on separate process
 
 _selected_bg_color = None
 _bg_color = None
@@ -99,14 +101,15 @@ def capture_references(new_editor_window):
     """
     global editor_window, media_list_view, bin_list_view, sequence_list_view, pos_bar, \
     tc, tline_display, tline_scale, tline_canvas, tline_scroll, tline_v_scroll, tline_info, \
-    tline_column, play_b, clip_editor_b, sequence_editor_b, \
+    tline_column, play_b, \
     effect_select_list_view, effect_select_combo_box, project_info_vbox, middle_notebook, big_tc, editmenu, notebook_buttons, tline_left_corner, \
-    monitor_widget
+    monitor_widget, bin_panel, monitor_switch
 
     editor_window = new_editor_window
 
     media_list_view = editor_window.media_list_view
     bin_list_view = editor_window.bin_list_view
+    bin_panel = editor_window.bins_panel
     sequence_list_view = editor_window.sequence_list_view
 
     middle_notebook = editor_window.notebook
@@ -118,7 +121,8 @@ def capture_references(new_editor_window):
     tc = editor_window.tc
 
     monitor_widget = editor_window.monitor_widget
-
+    monitor_switch = editor_window.monitor_switch
+    
     tline_display = editor_window.tline_display
     tline_scale = editor_window.tline_scale
     tline_canvas = editor_window.tline_canvas
@@ -127,9 +131,6 @@ def capture_references(new_editor_window):
     tline_column = editor_window.tline_column
     tline_left_corner = editor_window.left_corner
 
-    clip_editor_b = editor_window.clip_editor_b
-    sequence_editor_b = editor_window.sequence_editor_b
-
     big_tc = editor_window.big_TC
 
     editmenu = editor_window.uimanager.get_widget('/MenuBar/EditMenu')
@@ -146,8 +147,8 @@ def get_selected_bg_color():
     return _selected_bg_color
 
 # returns Gdk.RGBA color
-def get_buttons_color():
-    return _button_colors
+#def get_buttons_color():
+#    return _button_colors
 
 def set_theme_colors():
     # Find out if theme color discovery works and set selected bg color apppropiately when
@@ -164,7 +165,7 @@ def set_theme_colors():
     r, g, b, a = unpack_gdk_color(sel_bg_color)
     if r == 0.0 and g == 0.0 and b == 0.0:
         print "Selected color NOT detected"
-        if editorpersistance.prefs.dark_theme == False:
+        if editorpersistance.prefs.theme == appconsts.LIGHT_THEME:
             c = theme_colors[2]
         else:
             c = theme_colors[3]
@@ -176,11 +177,14 @@ def set_theme_colors():
     # Try to detect bg color and set frow fallback if fails
     style = editor_window.window.get_style_context()
     bg_color = style.get_background_color(Gtk.StateFlags.NORMAL)
+    if editorpersistance.prefs.theme == appconsts.FLOWBLADE_THEME:
+        bg_color = Gdk.RGBA(red=(30.0/255.0), green=(35.0/255.0), blue=(51.0/255.0), alpha=1.0)
+
     r, g, b, a = unpack_gdk_color(bg_color)
 
     if r == 0.0 and g == 0.0 and b == 0.0:
         print "BG color NOT detected"
-        if editorpersistance.prefs.dark_theme == False:
+        if editorpersistance.prefs.theme == appconsts.LIGHT_THEME:
             c = theme_colors[0]
         else:
             c = theme_colors[1]
@@ -191,11 +195,25 @@ def set_theme_colors():
         _bg_color = bg_color
         _button_colors = bg_color
 
+    if editorpersistance.prefs.theme == appconsts.FLOWBLADE_THEME:
+        theme_colors = _THEME_COLORS[4]
+        c = theme_colors[3]
+        _selected_bg_color = Gdk.RGBA(*c) 
+
     # Adwaita and some others show big area of black without this, does not bother Ambient on Ubuntu
     editor_window.tline_pane.override_background_color(Gtk.StateFlags.NORMAL, get_bg_color())
     editor_window.media_panel.override_background_color(Gtk.StateFlags.NORMAL, get_bg_color())
     editor_window.mm_paned.override_background_color(Gtk.StateFlags.NORMAL, get_bg_color())
 
+def apply_flowblade_theme_fixes():
+    fblade_bg_color = Gdk.RGBA(red=(30.0/255.0), green=(35.0/255.0), blue=(51.0/255.0), alpha=1.0)
+    fblade_bg_color_darker = Gdk.RGBA(red=(16.0/255.0), green=(19.0/255.0), blue=(30.0/255.0), alpha=1.0)
+    test_color =  Gdk.RGBA(1, 0, 0, alpha=1.0)
+    for widget in editor_window.fblade_theme_fix_panels:
+        widget.override_background_color(Gtk.StateFlags.NORMAL, fblade_bg_color)
+    for widget in editor_window.fblade_theme_fix_panels_darker:
+        widget.override_background_color(Gtk.StateFlags.NORMAL, fblade_bg_color_darker)
+        
 def unpack_gdk_color(gdk_color):
     return (gdk_color.red, gdk_color.green, gdk_color.blue, gdk_color.alpha)
 
@@ -218,7 +236,7 @@ def load_current_colors():
 
 def _colors_data_path():
     return utils.get_hidden_user_dir_path() + _CURRENT_THEME_COLORS_FILE
-
+  
 def _print_widget(widget): # debug
     path_str = widget.get_path().to_string()
     path_str = path_str.replace("GtkWindow:dir-ltr.background","")
@@ -229,3 +247,20 @@ def _print_widget(widget): # debug
     path_str = path_str.replace("GtkVBox:. GtkVPaned:[2/2]. GtkHBox:. GtkHPaned:. GtkVBox:. GtkNotebook:[1/1]","notebook:")
     print path_str
 
+def apply_gtk_css():
+    gtk_version = "%s.%s.%s" % (Gtk.get_major_version(), Gtk.get_minor_version(), Gtk.get_micro_version())
+    if Gtk.get_major_version() == 3 and Gtk.get_minor_version() >= 22:
+        print "Gtk version is " + gtk_version + ", Flowblade theme is available."
+    else:
+        print "Gtk version is " + gtk_version + ", Flowblade theme only available for Gtk >= 3.22"
+        editorpersistance.prefs.theme = appconsts.LIGHT_THEME
+        editorpersistance.save()
+        return False
+        
+    provider = Gtk.CssProvider.new()
+    display = Gdk.Display.get_default()
+    screen = display.get_default_screen()
+    Gtk.StyleContext.add_provider_for_screen (screen, provider, Gtk.STYLE_PROVIDER_PRIORITY_USER)
+    provider.load_from_path(respaths.ROOT_PATH + "/res/css/gtk-flowblade-dark.css")
+
+    return True
