@@ -22,27 +22,26 @@
 Module handles keyevents.
 """
 
-from gi.repository import Gtk
 from gi.repository import Gdk
 
-import appconsts
 import audiowaveform
 import clipeffectseditor
 import compositeeditor
 import compositormodes
 import glassbuttons
 import gui
-import editevent
 import editorpersistance
 import editorstate
 from editorstate import current_sequence
 from editorstate import PLAYER
 from editorstate import timeline_visible
 import keyframeeditor
+import kftoolmode
 import medialog
 import menuactions
+import modesetting
 import monitorevent
-import mltrefhold
+import multitrimmode
 # Apr-2017 - SvdB
 import shortcuts
 import re
@@ -51,8 +50,8 @@ import tlinewidgets
 import trimmodes
 import updater
 import projectaction
+import workflow
 
-import audiowaveformrenderer
 
 
 # ------------------------------------- keyboard events
@@ -66,7 +65,7 @@ def key_down(widget, event):
             audiowaveform.waveform_thread.abort_rendering()
             return True
         elif editorstate.current_is_move_mode() == False:
-            editevent.set_default_edit_mode()
+            modesetting.set_default_edit_mode()
             return True
         elif gui.big_tc.get_visible_child_name() == "BigTCEntry":
             gui.big_tc.set_visible_child_name("BigTCDisplay")
@@ -96,25 +95,42 @@ def key_down(widget, event):
 
     # Insert shortcut keys need more focus then timeline shortcuts.
     # these may already have been handled in timeline focus events
-    was_handled = _handle_extended_tline_focus_events(event)
+    was_handled = _handle_extended_monitor_focus_events(event)
     if was_handled:
         # Stop event handling here
         return True
 
     # Pressing timeline button obivously leaves user expecting
     # to have focus in timeline
+    """
+    TODO: this needs something
     if gui.sequence_editor_b.has_focus():
         _handle_tline_key_event(event)
         # Stop event handling here
         return True
-
+    """
+    
     # Clip button or posbar focus with clip displayed leaves playback keyshortcuts available
-    if (gui.clip_editor_b.has_focus() 
+    """
+    if (gui.clip_editor_b.has_focus()
+        TODO: this needs something
         or (gui.pos_bar.widget.is_focus() and (not timeline_visible()))):
         _handle_clip_key_event(event)
         # Stop event handling here
         return True
+    """
+    if gui.monitor_switch.widget.has_focus() and timeline_visible():
+        _handle_tline_key_event(event)
+        return True
 
+    if gui.monitor_switch.widget.has_focus() and (not timeline_visible()):
+        _handle_clip_key_event(event)
+        return True
+        
+    if gui.pos_bar.widget.is_focus() and (not timeline_visible()):
+        _handle_clip_key_event(event)
+        return True
+        
     #  Handle non-timeline delete 
     if event.keyval == Gdk.KEY_Delete:
         return _handle_delete()
@@ -149,7 +165,7 @@ def key_down(widget, event):
     #debug
     if event.keyval == Gdk.KEY_F12:
         if (event.get_state() & Gdk.ModifierType.CONTROL_MASK):
-            pass
+            tlineaction.ripple_delete_button_pressed()
         return True
 
     # Key event was not handled here.
@@ -158,7 +174,7 @@ def key_down(widget, event):
 def _timeline_has_focus():
     if(gui.tline_canvas.widget.has_focus()
        or gui.tline_column.widget.has_focus()
-       or gui.editor_window.modes_selector.widget.has_focus()
+       or gui.editor_window.tool_selector.widget.has_focus()
        or (gui.pos_bar.widget.has_focus() and timeline_visible())
        or gui.tline_scale.widget.has_focus()
        or glassbuttons.focus_group_has_focus(glassbuttons.DEFAULT_FOCUS_GROUP)):
@@ -172,10 +188,12 @@ def _handle_tline_key_event(event):
     Returns True for handled key presses to stop those
     keyevents from going forward.
     """
-    # Apr-2017 - SvdB - For keyboard shortcuts
-    action = _get_shortcut_action(event)
+
+    tool_was_selected = workflow.tline_tool_keyboard_selected(event)
+    if tool_was_selected == True:
+        return True
     
-    # Apr-2017 - SvdB - For ffwd / rev speeds
+    action = _get_shortcut_action(event)
     prefs = editorpersistance.prefs
 
     if action == 'mark_in':
@@ -205,46 +223,23 @@ def _handle_tline_key_event(event):
         return True
     if action == 'add_marker':
         tlineaction.add_marker()
-        return True
-    if action == 'edit_mode_insert':
-        gui.editor_window.handle_insert_move_mode_button_press()
-        gui.editor_window.set_mode_selector_to_mode()
-        return True
-    if action == 'edit_mode_overwrite':
-        gui.editor_window.handle_over_move_mode_button_press()
-        gui.editor_window.set_mode_selector_to_mode()
-        return True
-    if action == 'edit_mode_trim':
-        gui.editor_window.handle_one_roll_mode_button_press()
-        gui.editor_window.set_mode_selector_to_mode()
-        return True
-    if action == 'edit_mode_roll':
-        gui.editor_window.handle_two_roll_mode_button_press()
-        gui.editor_window.set_mode_selector_to_mode()
-        return True
-    if action == 'edit_mode_slip':
-        gui.editor_window.handle_slide_mode_button_press()
-        gui.editor_window.set_mode_selector_to_mode()
-        return True
-    if action == 'edit_mode_spacer':
-        gui.editor_window.handle_multi_mode_button_press()
-        gui.editor_window.set_mode_selector_to_mode()
-        return True
-    if action == 'edit_mode_box':
-        gui.editor_window.handle_box_mode_button_press()
-        gui.editor_window.set_mode_selector_to_mode()
-        return True
+        return True    
     if action == 'cut':
         tlineaction.cut_pressed()
         return True
+    if action == 'cut_all':
+        tlineaction.cut_all_pressed()
+        return True
+    if action == 'sequence_split':
+        tlineaction.sequence_split_pressed()
+        return True
     if action == 'log_range':
         medialog.log_range_clicked()
         return True
     if action == 'toggle_ripple':
         gui.editor_window.toggle_trim_ripple_mode()
         return True
-    
-    
+
     # Key bindings for keyboard trimming
     if editorstate.current_is_active_trim_mode() == True:
         if action == 'prev_frame':
@@ -257,6 +252,10 @@ def _handle_tline_key_event(event):
             trimmodes.enter_pressed()
             return True
 
+
+    if editorstate.EDIT_MODE() == editorstate.MULTI_TRIM:
+        multitrimmode.enter_pressed()
+
     # Key bindings for MOVE MODES and _NO_EDIT modes
     if editorstate.current_is_move_mode() or editorstate.current_is_active_trim_mode() == False:
         if action == 'next_cut':
@@ -326,10 +325,13 @@ def _handle_tline_key_event(event):
             tlineaction.resync_button_pressed()
             return True
         if action == 'delete':
-            # Clip selection and compositor selection are mutually exclusive, 
-            # so max one one these will actually delete something
-            tlineaction.splice_out_button_pressed()
-            compositormodes.delete_current_selection()
+            if editorstate.EDIT_MODE() == editorstate.KF_TOOL:
+                kftoolmode.delete_active_keyframe()
+            else:
+                # Clip selection and compositor selection are mutually exclusive, 
+                # so max one one these will actually delete something
+                tlineaction.splice_out_button_pressed()
+                compositormodes.delete_current_selection()
         if action == 'to_start':
             if PLAYER().is_playing():
                 monitorevent.stop_pressed()
@@ -346,33 +348,29 @@ def _handle_tline_key_event(event):
         if action == 'to_start':
             if PLAYER().is_playing():
                 monitorevent.stop_pressed()
-            gui.editor_window.handle_insert_move_mode_button_press()
-            gui.editor_window.set_mode_selector_to_mode()
+            gui.editor_window.set_default_edit_tool()
             PLAYER().seek_frame(0)
             _move_to_beginning()
             return True
         if action == 'to_end':
             if PLAYER().is_playing():
                 monitorevent.stop_pressed()
-            gui.editor_window.handle_insert_move_mode_button_press()
-            gui.editor_window.set_mode_selector_to_mode()
+            gui.editor_window.set_default_edit_tool()
             PLAYER().seek_end()
             _move_to_end()
             return True
 
     return False
 
-
-def _handle_extended_tline_focus_events(event):
-    # This function was added to fix to a bug long time ago but the rationale for "extended_tline_focus_events" has been forgotten, but probably still exists
+def _handle_extended_monitor_focus_events(event):
+    # This function was added to get a subset of events only to work when monitor has focus
     # Apr-2017 - SvdB - For keyboard shortcuts
     action = _get_shortcut_action(event)
 
     # We're dropping monitor window in 2 window mode as part of timeline focus
-    if not(_timeline_has_focus() or
-            gui.pos_bar.widget.has_focus() or
-            gui.sequence_editor_b.has_focus() or
-            gui.clip_editor_b.has_focus()):
+    #    TODO:        gui.sequence_editor_b.has_focus() or
+    #        gui.clip_editor_b.has_focus()):
+    if not(gui.monitor_switch.widget.has_focus() or gui.pos_bar.widget.has_focus()):
         return False
 
     if action == '3_point_overwrite':
@@ -399,33 +397,9 @@ def _handle_extended_tline_focus_events(event):
     if action == 'switch_monitor':
         updater.switch_monitor_display()
         return True
-    if action == 'edit_mode_insert':
-        gui.editor_window.handle_insert_move_mode_button_press()
-        gui.editor_window.set_mode_selector_to_mode()
-        return True
-    if action == 'edit_mode_overwrite':
-        gui.editor_window.handle_over_move_mode_button_press()
-        gui.editor_window.set_mode_selector_to_mode()
-        return True
-    if action == 'edit_mode_trim':
-        gui.editor_window.handle_one_roll_mode_button_press()
-        gui.editor_window.set_mode_selector_to_mode()
-        return True
-    if action == 'edit_mode_roll':
-        gui.editor_window.handle_two_roll_mode_button_press()
-        gui.editor_window.set_mode_selector_to_mode()
-        return True
-    if action == 'edit_mode_slip':
-        gui.editor_window.handle_slide_mode_button_press()
-        gui.editor_window.set_mode_selector_to_mode()
-        return True
-    if action == 'edit_mode_spacer':
-        gui.editor_window.handle_multi_mode_button_press()
-        gui.editor_window.set_mode_selector_to_mode()
-        return True
-    if action == 'edit_mode_box':
-        gui.editor_window.handle_box_mode_button_press()
-        gui.editor_window.set_mode_selector_to_mode()
+    
+    tool_was_selected = workflow.tline_tool_keyboard_selected(event)
+    if tool_was_selected == True:
         return True
 
     return False
@@ -594,7 +568,7 @@ def _handle_geometry_editor_keys(event):
                         or (event.keyval == Gdk.KEY_Right)
                         or (event.keyval == Gdk.KEY_Up)
                         or (event.keyval == Gdk.KEY_Down)):
-                        kfeditor.arrow_edit(event.keyval, (event.get_state() & Gdk.ModifierType.CONTROL_MASK))
+                        kfeditor.arrow_edit(event.keyval, (event.get_state() & Gdk.ModifierType.CONTROL_MASK), (event.get_state() & Gdk.ModifierType.SHIFT_MASK))
                         return True
                     if event.keyval == Gdk.KEY_plus:
                         pass # not impl
