@@ -37,6 +37,7 @@ import dialogs
 import dialogutils
 import editorstate
 import editorpersistance
+import gui
 import guiutils
 import guicomponents
 import mltenv
@@ -45,6 +46,7 @@ import mlttransitions
 import mltfilters
 import patternproducer
 import persistance
+import processutils
 import projectdata
 import propertyparse
 import respaths
@@ -432,7 +434,7 @@ def _set_button_pressed():
 
 def _set_relink_path(media_asset):
     file_name = os.path.basename(media_asset.orig_path)
-    dialogs.media_file_dialog(_("Select Media File To Relink To") + " " + file_name, 
+    dialogs.media_file_dialog(_("Select Media File To Relink To") + " " + file_name.decode('utf-8'), 
                                 _select_relink_path_dialog_callback, False, 
                                 media_asset, linker_window, last_media_dir)
 
@@ -588,12 +590,15 @@ def main(root_path, filename):
     Gdk.threads_init()
     Gdk.threads_enter()
 
-    # Request dark them if so desired
-    if editorpersistance.prefs.dark_theme == True:
+    # Themes
+    if editorpersistance.prefs.theme != appconsts.LIGHT_THEME:
         Gtk.Settings.get_default().set_property("gtk-application-prefer-dark-theme", True)
+        if editorpersistance.prefs.theme == appconsts.FLOWBLADE_THEME:
+            gui.apply_gtk_css()
 
     repo = mlt.Factory().init()
-
+    processutils.prepare_mlt_repo(repo)
+    
     # Set numeric locale to use "." as radix, MLT initilizes this to OS locale and this causes bugs 
     locale.setlocale(locale.LC_NUMERIC, 'C')
 
