@@ -18,7 +18,6 @@
     along with Flowblade Movie Editor. If not, see <http://www.gnu.org/licenses/>.
 """
 
-import cairo
 import datetime
 
 from gi.repository import Gtk
@@ -28,7 +27,6 @@ from gi.repository import Pango
 
 import appconsts
 import dialogs
-import dialogutils
 import dnd
 import edit
 import gui
@@ -45,7 +43,7 @@ import utils
 
 widgets = utils.EmptyClass()
 
-do_multiple_clip_insert_func = None # this mankeypathched her in app.py
+do_multiple_clip_insert_func = None # this is monkeypathched here in app.py
 
 actions_popup_menu = Gtk.Menu()        
 
@@ -57,7 +55,9 @@ COMMENT_SORT = appconsts.COMMENT_SORT
 sorting_order = TIME_SORT
 
 range_log_notebook_index = 1 # this is set 0 for 2 window mode
-                
+
+
+# ----------------------------------- log data object
 class MediaLogEvent:
     def __init__(self, event_type, mark_in, mark_out, name, path):
         self.event_type = event_type
@@ -248,8 +248,15 @@ def append_log_events():
     for le in log_events:
         clips.append(get_log_event_clip(le))
     
-    track = editorstate.current_sequence().get_first_active_track() # audio tracks??!!??
-    
+    track = editorstate.current_sequence().get_first_active_track()
+
+    # Can't put audio media on video track
+    for new_clip in clips:
+        if ((new_clip.media_type == appconsts.AUDIO)
+           and (track.type == appconsts.VIDEO)):
+            dialogs.no_audio_dialog(track)
+            return
+
     data = {"track":track,
             "clips":clips}
 
@@ -367,13 +374,6 @@ def _group_action_pressed(widget, event):
         name_item.set_active(True)
     else:# "comment"
         comment_item.set_active(True)
-        
-    """
-    if editorpersistance.prefs.midbar_tc_left == True:
-        tc_left.set_active(True)
-    else:
-        tc_middle.set_active(True)
-    """
 
     sort_item.set_submenu(sort_menu)
     sort_item.show()
@@ -649,8 +649,8 @@ class MediaLogListView(Gtk.VBox):
 def get_media_log_events_panel(events_list_view):
     global widgets
 
-    actions_surface = cairo.ImageSurface.create_from_png(respaths.IMAGE_PATH + "media_log_action.png")
-    group_actions_menu = guicomponents.PressLaunch(_group_action_pressed, actions_surface, 38, 22)
+    group_actions_menu = guicomponents.HamburgerPressLaunch(_group_action_pressed)
+    guiutils.set_margins(group_actions_menu.widget, 10, 0, 2, 18)
 
     star_check = Gtk.CheckButton()
     star_check.set_active(True)
@@ -682,7 +682,6 @@ def get_media_log_events_panel(events_list_view):
     
     row1 = Gtk.HBox()
     row1.pack_start(guiutils.get_pad_label(6, 12), False, True, 0)
-    row1.pack_start(group_actions_menu.widget, False, True, 0)
     row1.pack_start(guiutils.get_pad_label(6, 12), False, True, 0)
     row1.pack_start(widgets.group_box, False, True, 0)
     row1.pack_start(guiutils.get_pad_label(6, 12), False, True, 0)
@@ -722,6 +721,7 @@ def get_media_log_events_panel(events_list_view):
     append_displayed.connect("clicked", lambda w:append_log_events())
 
     row2 =  Gtk.HBox()
+    row2.pack_start(group_actions_menu.widget, False, True, 0)
     row2.pack_start(widgets.log_range, False, True, 0)
     row2.pack_start(delete_button, False, True, 0)
     row2.pack_start(Gtk.Label(), True, True, 0)
