@@ -71,65 +71,66 @@ wipe_lumas = None # User displayed name -> resource image
 compositors = None
 blenders = None
 autofades = None
+alpha_combiners = None
 
 def init_module():
 
     # translations and module load order make us do this in method instead of at module load
-    global wipe_lumas, compositors, blenders, name_for_type, rendered_transitions, single_track_render_type_names, autofades
+    global wipe_lumas, compositors, blenders, name_for_type, rendered_transitions, single_track_render_type_names, autofades, alpha_combiners
     wipe_lumas = { \
                 _("Vertical From Center"):"bi-linear_x.pgm",
-                _("Vertical Top to Bottom"):"wipe_top_to_bottom.svg",
-                _("Vertical Bottom to Top"):"wipe_bottom_to_top.svg",
+                _("Vertical Top to Bottom"):"wipe_top_to_bottom.pgm",
+                _("Vertical Bottom to Top"):"wipe_bottom_to_top.pgm",
                 _("Horizontal From Center"):"bi-linear_y.pgm",
-                _("Horizontal Left to Right"):"wipe_left_to_right.svg",
-                _("Horizontal Right to Left"):"wipe_right_to_left.svg",
+                _("Horizontal Left to Right"):"wipe_left_to_right.pgm",
+                _("Horizontal Right to Left"):"wipe_right_to_left.pgm",
                 _("Clock Left To Right"):"clock_left_to_right.pgm",
                 _("Clock Right to Left"):"clock_right_to_left.pgm",
                 _("Clock Symmetric"):"symmetric_clock.pgm",
                 _("Stripes Horizontal"):"blinds_in_to_out.pgm",
                 _("Stripes Horizontal Big"):"blinds_in_to_out_big.pgm",
-                _("Stripes Horizontal Moving"):"blinds_sliding.png",
+                _("Stripes Horizontal Moving"):"blinds_sliding.pgm",
                 _("Stripes Vertical"):"vertical_blinds_in_to_out.pgm",
                 _("Stripes Vertical Big"):"vertical_blinds_in_to_out_big.pgm",
                 _("Burst"):"burst.pgm",
-                _("Circle From In"):"circle_in_to_out.svg",
-                _("Circle From Out"):"circle_out_to_in.svg",
+                _("Circle From In"):"circle_in_to_out.pgm",
+                _("Circle From Out"):"circle_out_to_in.pgm",
                 _("Cloud"):"cloud.pgm",
-                _("Hatched 1"):"hatched_1.png",
-                _("Hatched 2"):"hatched_2.png",
-                _("Hourglass"):"hourglass_1.png",
-                _("Puddles"):"mountains.png",
+                _("Hatched 1"):"hatched_1.pgm",
+                _("Hatched 2"):"hatched_2.pgm",
+                _("Hourglass"):"hourglass_1.pgm",
+                _("Puddles"):"mountains.pgm",
                 _("Rings"):"radial-bars.pgm",
                 _("Rectangle From In"):"rectangle_in_to_out.pgm",
                 _("Rectangle From Out"):"rectangle_out_to_in.pgm",
                 _("Rectangle Bars"):"square2-bars.pgm",
-                _("Sand"):"sand.svg",
-                _("Sphere"):"sphere.png",
-                _("Spiral Abstract"):"spiral_abstract_1.png",
+                _("Sand"):"sand.pgm",
+                _("Sphere"):"sphere.pgm",
+                _("Spiral Abstract"):"spiral_abstract_1.pgm",
                 _("Spiral"):"spiral.pgm",
                 _("Spiral Galaxy"):"spiral2.pgm",
                 _("Spiral Big"):"spiral_big.pgm",
                 _("Spiral Medium"):"spiral_medium.pgm",
-                _("Spots"):"spots.png",
-                _("Star"):"star_2.png",
-                _("Arch"):"fractal_1.png",
-                _("Patches"):"fractal_4.png",
-                _("Free Stripes"):"fractal_5.png",
-                _("Free Curves"):"fractal_7.png",
-                _("Diagonal 1"):"wipe_diagonal_1.png",
-                _("Diagonal 2"):"wipe_diagonal_2.png",
-                _("Diagonal 3"):"wipe_diagonal_3.png",
-                _("Diagonal 4"):"wipe_diagonal_4.png",
+                _("Spots"):"spots.pgm",
+                _("Star"):"star_2.pgm",
+                _("Arch"):"fractal_1.pgm",
+                _("Patches"):"fractal_4.pgm",
+                _("Free Stripes"):"fractal_5.pgm",
+                _("Free Curves"):"fractal_7.pgm",
+                _("Diagonal 1"):"wipe_diagonal_1.pgm",
+                _("Diagonal 2"):"wipe_diagonal_2.pgm",
+                _("Diagonal 3"):"wipe_diagonal_3.pgm",
+                _("Diagonal 4"):"wipe_diagonal_4.pgm",
                 _("Checkerboard"):"checkerboard_small.pgm"}
 
     # name -> mlt_compositor_transition_infos key dict.
-    unsorted_compositors = [ (_("Affine"),"##affine"),
-                             (_("Dissolve"),"##opacity_kf"),
+    unsorted_compositors = [ (_("Dissolve"),"##opacity_kf"),
                              (_("Picture in Picture"),"##pict_in_pict"),
                              (_("Region"), "##region"),
                              (_("Affine Blend"), "##affineblend"),
                              (_("Blend"), "##blend"),
-                             (_("Wipe Clip Length"),"##wipe")]
+                             (_("Wipe Clip Length"),"##wipe"),
+                             (_("Transform"),"##affine")]
 
     compositors = sorted(unsorted_compositors, key=lambda comp: comp[0])   
 
@@ -157,6 +158,15 @@ def init_module():
     autofades = [(_("Fade In"),"##auto_fade_in"),
                 (_("Fade Out"),"##auto_fade_out")]
     
+    alpha_combiners = [ (_("Alpha XOR"),"##alphaxor"),
+                        (_("Alpha Out"),"##alphaout"),
+                        (_("Alpha In"),"##alphain")]
+
+    """ These ain't doing correct Porter-Duff
+                        (_("Alpha Over"),"##alphaover"),
+                        (_("Alpha Atop"),"##alphaatop")]
+    """
+                        
     for comp in compositors:
         name, comp_type = comp
         name_for_type[comp_type] = name
@@ -168,6 +178,10 @@ def init_module():
     for fade in autofades:
         name, comp_type = fade
         name_for_type[comp_type] = name
+
+    for acomb in alpha_combiners:
+        name, comp_type = acomb
+        name_for_type[comp_type] = name
         
     # Rendered transition names and types
     rendered_transitions = [  (_("Dissolve"), RENDERED_DISSOLVE), 
@@ -295,7 +309,7 @@ class CompositorTransition:
             fval = 1
         else:
             fval = 0
-        self.mlt_transition.set("force_track",str(fval))
+        self.mlt_transition.set("force_track", str(fval))
 
     def update_editable_mlt_properties(self):
         for prop in self.properties:
@@ -433,6 +447,15 @@ def is_blender(compositor_type_test):
     
     return False
 
+def is_alpha_combiner(compositor_type_test):
+    for acomb in alpha_combiners:
+        name, compositor_type = acomb
+        if compositor_type_test == compositor_type:
+            return True
+    
+    return False
+
+
 # ------------------------------------------------------ rendered transitions
 # These are tractor objects used to create rendered transitions.
 def get_rendered_transition_tractor(current_sequence, 
