@@ -25,13 +25,11 @@ are used to build gui at callsites.
 import cairo
 
 from gi.repository import Gtk, Gdk
-from gi.repository import GdkPixbuf
 
 import appconsts
 import gui
 import guicomponents
 import guiutils
-import editorpersistance
 import editorstate
 import mlttransitions
 import renderconsumer
@@ -47,25 +45,15 @@ MEDIA_PANEL_MAX_ROWS = 8
 MEDIA_PANEL_DEFAULT_ROWS = 2
 
 
-def get_media_files_panel(media_list_view, add_cb, del_cb, col_changed_cb, proxy_cb, filtering_cb):
-    # Create buttons and connect signals
-    add_media_b = Gtk.Button(_("Add"))
-    del_media_b = Gtk.Button(_("Delete"))    
-    add_media_b.connect("clicked", add_cb, None)
-    del_media_b.connect("clicked", del_cb, None)
-    add_media_b.set_tooltip_text(_("Add Media File to Bin"))
-    del_media_b.set_tooltip_text(_("Delete Media File from Bin"))
-
-    proxy_b = Gtk.Button()
-    proxy_b.set_image(Gtk.Image.new_from_file(respaths.IMAGE_PATH + "proxy_button.png"))
-    proxy_b.connect("clicked", proxy_cb, None)
-    proxy_b.set_tooltip_text(_("Render Proxy Files For Selected Media"))
-    gui.proxy_button = proxy_b
+def get_media_files_panel(media_list_view, add_cb, del_cb, col_changed_cb, hamburger_launch_pressed, filtering_cb):   
+    hamburger_launcher = guicomponents.HamburgerPressLaunch(hamburger_launch_pressed)
+    guiutils.set_margins(hamburger_launcher.widget, 2, 0, 4, 12)
 
     columns_img = cairo.ImageSurface.create_from_png(respaths.IMAGE_PATH + "columns.png")
     columns_launcher = guicomponents.PressLaunch(col_changed_cb, columns_img, w=22, h=22)
-    columns_launcher.surface_y = 9
-
+    columns_launcher.surface_y = 6
+    columns_launcher.widget.set_tooltip_text(_("Number of Media File columns."))
+    
     all_pixbuf = cairo.ImageSurface.create_from_png(respaths.IMAGE_PATH + "show_all_files.png")
     audio_pixbuf = cairo.ImageSurface.create_from_png(respaths.IMAGE_PATH + "show_audio_files.png")
     graphics_pixbuf = cairo.ImageSurface.create_from_png(respaths.IMAGE_PATH + "show_graphics_files.png")
@@ -75,41 +63,33 @@ def get_media_files_panel(media_list_view, add_cb, del_cb, col_changed_cb, proxy
 
     files_filter_launcher = guicomponents.ImageMenuLaunch(filtering_cb, [all_pixbuf, video_pixbuf, audio_pixbuf, graphics_pixbuf, imgseq_pixbuf, pattern_pixbuf], 24, 22)
     files_filter_launcher.surface_x  = 3
-    files_filter_launcher.surface_y  = 8
+    files_filter_launcher.surface_y  = 4
+    files_filter_launcher.widget.set_tooltip_text(_("Visible Media File types."))
     gui.media_view_filter_selector = files_filter_launcher
 
+    bin_info = guicomponents.BinInfoPanel()
+    
     buttons_box = Gtk.HBox(False,1)
-    buttons_box.pack_start(add_media_b, True, True, 0)
-    buttons_box.pack_start(del_media_b, True, True, 0)
-    buttons_box.pack_start(proxy_b, False, False, 0)
+    buttons_box.pack_start(hamburger_launcher.widget, False, False, 0)
     buttons_box.pack_start(guiutils.get_pad_label(4, 4), False, False, 0)
     buttons_box.pack_start(columns_launcher.widget, False, False, 0)
     buttons_box.pack_start(files_filter_launcher.widget, False, False, 0)
+    buttons_box.pack_start(Gtk.Label(), True, True, 0)
+    buttons_box.pack_start(bin_info, False, False, 0)
+    #buttons_box.pack_start(Gtk.Label(), True, True, 0)
 
     panel = Gtk.VBox()
-    panel.pack_start(buttons_box, False, True, 0)
     panel.pack_start(media_list_view, True, True, 0)
-    
-    return panel
-
-def get_bins_panel(bin_list_view, add_cb, delete_cb):
-    # Create buttons and connect signals
-    add_b = Gtk.Button(_("Add"))
-    del_b = Gtk.Button(_("Delete"))
-    add_b.connect("clicked", add_cb, None)
-    del_b.connect("clicked", delete_cb, None)
-    add_b.set_tooltip_text(_("Add Bin to Project"))
-    del_b.set_tooltip_text(_("Delete Bin from Project"))
-    buttons_box = Gtk.HBox(True,1)
-    buttons_box.pack_start(add_b, True, True, 0)
-    buttons_box.pack_start(del_b, True, True, 0)
-    
-    panel = Gtk.VBox()
     panel.pack_start(buttons_box, False, True, 0)
+
+    return (panel, bin_info)
+
+def get_bins_tree_panel(bin_list_view):   
+    panel = Gtk.VBox()
     panel.pack_start(bin_list_view, True, True, 0)
 
-    return get_named_frame(_("Bins"), panel, 0, 0, 0)
-
+    return get_named_frame(_("Bins"), panel, 0, 0, 0, "A <b>Bin</b> is a named collection of media.")
+    
 def get_sequences_panel(sequence_list_view, edit_seq_cb, add_seq_cb, del_seq_cb):
     # Create buttons and connect signals
     add_b = Gtk.Button(_("Add"))
@@ -128,10 +108,10 @@ def get_sequences_panel(sequence_list_view, edit_seq_cb, add_seq_cb, del_seq_cb)
     buttons_box.pack_start(del_b, True, True, 0)
     
     panel = Gtk.VBox()
-    panel.pack_start(buttons_box, False, True, 0)
+    #panel.pack_start(buttons_box, False, True, 0)
     panel.pack_start(sequence_list_view, True, True, 0)
 
-    return get_named_frame(_("Sequences"), panel, 4)
+    return get_named_frame(_("Sequences"), panel, 0, 6, 4, _("A <b>Sequence</b> is the full contents of the timeline creating a program, a movie."))
 
 def get_thumbnail_select_panel(current_folder_path):    
     texts_panel = get_two_text_panel(_("Select folder for new thumbnails."), 
@@ -190,7 +170,7 @@ def get_motion_render_progress_panel(file_name, progress_bar):
     return alignment
 """
 
-def get_named_frame(name, widget, left_padding=12, right_padding=6, right_out_padding=4):
+def get_named_frame(name, widget, left_padding=12, right_padding=6, right_out_padding=4, tooltip_txt=None):
     """
     Gnome style named panel
     """
@@ -201,6 +181,8 @@ def get_named_frame(name, widget, left_padding=12, right_padding=6, right_out_pa
         label_box = Gtk.HBox()
         label_box.pack_start(label, False, False, 0)
         label_box.pack_start(Gtk.Label(), True, True, 0)
+        if tooltip_txt != None:        
+            label.set_tooltip_markup(tooltip_txt)
 
     guiutils.set_margins(widget, right_padding, 0, left_padding, 0)
 
