@@ -26,12 +26,9 @@ import dialogutils
 import editorpersistance
 import gui
 import guiutils
-import guicomponents
 import mltprofiles
 # Jan-2017 - SvdB - To get the number of CPU cores
 import multiprocessing
-# Apr-2017 - SvdB
-import shortcuts
 
 PREFERENCES_WIDTH = 730
 PREFERENCES_HEIGHT = 440
@@ -169,15 +166,7 @@ def _edit_prefs_panel():
     gfx_length_spin.set_adjustment(spin_adj)
     gfx_length_spin.set_numeric(True)
 
-    trim_exit_on_empty = Gtk.CheckButton()
-    trim_exit_on_empty.set_active(prefs.empty_click_exits_trims)
-
-    quick_enter_trim = Gtk.CheckButton()
-    quick_enter_trim.set_active(prefs.quick_enter_trims)
-
-    remember_clip_frame = Gtk.CheckButton()
-    remember_clip_frame.set_active(prefs.remember_monitor_clip_frame)
-
+    """
     overwrite_clip_drop = Gtk.ComboBoxText()
     active = 0
     if prefs.overwrite_clip_drop == False:
@@ -185,10 +174,14 @@ def _edit_prefs_panel():
     overwrite_clip_drop.append_text(_("Overwrite blanks"))
     overwrite_clip_drop.append_text(_("Always insert"))
     overwrite_clip_drop.set_active(active)
+    """
+    
+    kf_edit_playhead_move = Gtk.CheckButton()
+    kf_edit_playhead_move.set_active(prefs.kf_edit_init_affects_playhead)
 
     cover_delete = Gtk.CheckButton()
     cover_delete.set_active(prefs.trans_cover_delete)
-    
+        
     active = 0
     if prefs.mouse_scroll_action_is_zoom == False:
         active = 1
@@ -197,30 +190,36 @@ def _edit_prefs_panel():
     mouse_scroll_action.append_text(_("Scroll Horizontal, Control to Zoom"))
     mouse_scroll_action.set_active(active)
 
+    active = 0
+    if prefs.scroll_horizontal_dir_up_forward == False:
+        active = 1
+    hor_scroll_dir = Gtk.ComboBoxText()
+    hor_scroll_dir.append_text(_("Scroll Up Forward"))
+    hor_scroll_dir.append_text(_("Scroll Down Forward"))
+    hor_scroll_dir.set_active(active)
+            
     hide_file_ext_button = Gtk.CheckButton()
     if hasattr(prefs, 'hide_file_ext'):
         hide_file_ext_button.set_active(prefs.hide_file_ext)
     
     # Layout
     row4 = _row(guiutils.get_two_column_box(Gtk.Label(label=_("Graphics default length:")), gfx_length_spin, PREFERENCES_LEFT))
-    row5 = _row(guiutils.get_checkbox_row_box(trim_exit_on_empty, Gtk.Label(label=_("Trim Modes exit on empty click"))))
-    row6 = _row(guiutils.get_checkbox_row_box(quick_enter_trim, Gtk.Label(label=_("Quick enter Trim Modes"))))
-    row7 = _row(guiutils.get_checkbox_row_box(remember_clip_frame, Gtk.Label(label=_("Remember Monitor Clip Frame"))))
-    row8 = _row(guiutils.get_two_column_box(Gtk.Label(label=_("Media drag'n'drop action on non-V1 tracks")), overwrite_clip_drop, PREFERENCES_LEFT))
+    #row8 = _row(guiutils.get_two_column_box(Gtk.Label(label=_("Media drag'n'drop action on non-V1 tracks:")), overwrite_clip_drop, PREFERENCES_LEFT))
     row9 = _row(guiutils.get_checkbox_row_box(cover_delete, Gtk.Label(label=_("Cover Transition/Fade clips on delete if possible"))))
     # Jul-2016 - SvdB - For play_pause button
-    row11 = _row(guiutils.get_two_column_box(Gtk.Label(label=_("Mouse Middle Button Scroll Action")), mouse_scroll_action, PREFERENCES_LEFT))
+    row11 = _row(guiutils.get_two_column_box(Gtk.Label(label=_("Mouse Middle Button Scroll Action:")), mouse_scroll_action, PREFERENCES_LEFT))
+    row13 = _row(guiutils.get_two_column_box(Gtk.Label(label=_("Mouse Horizontal Scroll Direction:")), hor_scroll_dir, PREFERENCES_LEFT))
+    row14 = _row(guiutils.get_checkbox_row_box(kf_edit_playhead_move, Gtk.Label(label=_("Move Playhead to Clip start on keyframe edit init"))))
     row12 = _row(guiutils.get_checkbox_row_box(hide_file_ext_button, Gtk.Label(label=_("Hide file extensions when importing Clips"))))
     # Apr-2017 - SvdB - For Fast Forward / Reverse options
     
     vbox = Gtk.VBox(False, 2)
-    vbox.pack_start(row5, False, False, 0)
-    vbox.pack_start(row6, False, False, 0)
     vbox.pack_start(row4, False, False, 0)
-    vbox.pack_start(row7, False, False, 0)
     vbox.pack_start(row9, False, False, 0)
-    vbox.pack_start(row8, False, False, 0)
+    #vbox.pack_start(row8, False, False, 0)
     vbox.pack_start(row11, False, False, 0)
+    vbox.pack_start(row13, False, False, 0)
+    vbox.pack_start(row14, False, False, 0)
     vbox.pack_start(row12, False, False, 0)
     vbox.pack_start(Gtk.Label(), True, True, 0)
 
@@ -228,16 +227,13 @@ def _edit_prefs_panel():
 
     # Jul-2016 - SvdB - Added play_pause_button
     # Apr-2017 - SvdB - Added ffwd / rev values
-    return vbox, (gfx_length_spin, trim_exit_on_empty, quick_enter_trim, remember_clip_frame, overwrite_clip_drop, cover_delete,
-                  mouse_scroll_action, hide_file_ext_button)
+    return vbox, (gfx_length_spin, cover_delete,
+                  mouse_scroll_action, hide_file_ext_button, hor_scroll_dir, kf_edit_playhead_move)
 
 def _playback_prefs_panel():
     prefs = editorpersistance.prefs
 
     # Widgets
-    auto_play_in_clip_monitor = Gtk.CheckButton()
-    auto_play_in_clip_monitor.set_active(prefs.auto_play_in_clip_monitor)
-
     auto_center_on_stop = Gtk.CheckButton()
     auto_center_on_stop.set_active(prefs.auto_center_on_play_stop)
     
@@ -249,6 +245,9 @@ def _playback_prefs_panel():
     
     auto_center_on_updown = Gtk.CheckButton()
     auto_center_on_updown.set_active(prefs.center_on_arrow_move)
+
+    follow_move_range = Gtk.CheckButton()
+    follow_move_range.set_active(prefs.playback_follow_move_tline_range)
     
     # Apr-2017 - SvdB - For FF/Rev speed options
     if hasattr(prefs, 'ffwd_rev_shift'):
@@ -276,7 +275,7 @@ def _playback_prefs_panel():
     ffwd_rev_caps_spin.set_numeric(True)
     
     # Layout
-    row1 = _row(guiutils.get_checkbox_row_box(auto_play_in_clip_monitor, Gtk.Label(label=_("Autoplay new Clips in Clip Monitor"))))
+    #row1 = _row(guiutils.get_checkbox_row_box(auto_play_in_clip_monitor, Gtk.Label(label=_("Autoplay new Clips in Clip Monitor"))))
     row2 = _row(guiutils.get_checkbox_row_box(auto_center_on_stop, Gtk.Label(label=_("Center Current Frame on Playback Stop"))))
     row13 = _row(guiutils.get_checkbox_row_box(auto_center_on_updown, Gtk.Label(label=_("Center Current Frame after Up/Down Arrow"))))
     # Jul-2016 - SvdB - For play_pause button
@@ -292,9 +291,11 @@ def _playback_prefs_panel():
     row15.set_tooltip_text(_("Speed of Forward / Reverse will be multiplied by this value if Ctrl Key is held (Only using KEYS)."))
     row16 = _row(guiutils.get_two_column_box(Gtk.Label(label=_("Fast Forward / Reverse Speed for Caps Lock Key:")), ffwd_rev_caps_spin, PREFERENCES_LEFT))
     row16.set_tooltip_text(_("Speed of Forward / Reverse will be multiplied by this value if Caps Lock is set (Only using KEYS)."))
+
+    row17 = _row(guiutils.get_checkbox_row_box(follow_move_range, Gtk.Label(label=_("Move Timeline to follow Playback"))))
     
     vbox = Gtk.VBox(False, 2)
-    vbox.pack_start(row1, False, False, 0)
+    vbox.pack_start(row17, False, False, 0)
     vbox.pack_start(row2, False, False, 0)
     vbox.pack_start(row13, False, False, 0)
     # Jul-2016 - SvdB - For play_pause button
@@ -309,9 +310,9 @@ def _playback_prefs_panel():
 
     # Jul-2016 - SvdB - Added play_pause_button
     # Apr-2017 - SvdB - Added ffwd / rev values
-    return vbox, (auto_play_in_clip_monitor, auto_center_on_stop, 
+    return vbox, (auto_center_on_stop, 
                   play_pause_button, auto_center_on_updown,
-                  ffwd_rev_shift_spin, ffwd_rev_ctrl_spin, ffwd_rev_caps_spin)
+                  ffwd_rev_shift_spin, ffwd_rev_ctrl_spin, ffwd_rev_caps_spin, follow_move_range)
                   
 def _view_prefs_panel():
     prefs = editorpersistance.prefs
@@ -330,18 +331,15 @@ def _view_prefs_panel():
     buttons_combo = Gtk.ComboBoxText()
     buttons_combo.append_text(_("Glass"))
     buttons_combo.append_text(_("Simple"))
-    if prefs.buttons_style == editorpersistance.GLASS_STYLE:
-        buttons_combo.set_active(0)
-    else:
-        buttons_combo.set_active(1)
+    buttons_combo.append_text(_("No Decorations"))
+    buttons_combo.set_active( prefs.buttons_style )
 
     dark_combo = Gtk.ComboBoxText()
-    dark_combo.append_text(_("Light Theme"))
+    dark_combo.append_text(_("Flowblade Theme"))
     dark_combo.append_text(_("Dark Theme"))
-    if prefs.dark_theme == True:
-        dark_combo.set_active(1)
-    else:
-        dark_combo.set_active(0)
+    dark_combo.append_text(_("Light Theme"))
+    dark_combo.set_active(prefs.theme)
+
 
     theme_combo = Gtk.ComboBoxText()
     for theme in gui._THEME_COLORS:
@@ -369,19 +367,26 @@ def _view_prefs_panel():
     tracks_combo.append_text(_("Double for HiDPI - 100px, 50px"))
     tracks_combo.set_active(prefs.double_track_hights)
 
+    top_row_layout = Gtk.ComboBoxText()
+    top_row_layout.append_text(_("3 panels if width (1450px+) available"))
+    top_row_layout.append_text(_("2 panels always"))
+    top_row_layout.set_active(prefs.top_row_layout)
+        
     # Layout
     row00 = _row(guiutils.get_two_column_box(Gtk.Label(label=_("Application window mode:")), window_mode_combo, PREFERENCES_LEFT))
-    row0 =  _row(guiutils.get_checkbox_row_box(force_english_check, Gtk.Label(label=_("Use English texts on localized OS"))))
-    row1 =  _row(guiutils.get_checkbox_row_box(display_splash_check, Gtk.Label(label=_("Display splash screen"))))
-    row2 =  _row(guiutils.get_two_column_box(Gtk.Label(label=_("Buttons style:")), buttons_combo, PREFERENCES_LEFT))
-    row3 =  _row(guiutils.get_two_column_box(Gtk.Label(label=_("Theme request, icons and colors:")), dark_combo, PREFERENCES_LEFT))
-    row4 =  _row(guiutils.get_two_column_box(Gtk.Label(label=_("Theme detection fail fallback colors:")), theme_combo, PREFERENCES_LEFT))
-    row5 =  _row(guiutils.get_two_column_box(Gtk.Label(label=_("Default audio levels display:")), audio_levels_combo, PREFERENCES_LEFT))
-    row7 =  _row(guiutils.get_two_column_box(Gtk.Label(label=_("Tracks Heights:")), tracks_combo, PREFERENCES_LEFT))
+    row0 = _row(guiutils.get_checkbox_row_box(force_english_check, Gtk.Label(label=_("Use English texts on localized OS"))))
+    row1 = _row(guiutils.get_checkbox_row_box(display_splash_check, Gtk.Label(label=_("Display splash screen"))))
+    row2 = _row(guiutils.get_two_column_box(Gtk.Label(label=_("Buttons style:")), buttons_combo, PREFERENCES_LEFT))
+    row3 = _row(guiutils.get_two_column_box(Gtk.Label(label=_("Theme request, icons and colors:")), dark_combo, PREFERENCES_LEFT))
+    row4 = _row(guiutils.get_two_column_box(Gtk.Label(label=_("Theme detection fail fallback colors:")), theme_combo, PREFERENCES_LEFT))
+    row5 = _row(guiutils.get_two_column_box(Gtk.Label(label=_("Default audio levels display:")), audio_levels_combo, PREFERENCES_LEFT))
+    row7 = _row(guiutils.get_two_column_box(Gtk.Label(label=_("Tracks Heights:")), tracks_combo, PREFERENCES_LEFT))
 
     # Feb-2017 - SvdB - For full file names
     row6 =  _row(guiutils.get_checkbox_row_box(show_full_file_names, Gtk.Label(label=_("Show Full File names"))))
 
+    row8 =  _row(guiutils.get_two_column_box(Gtk.Label(label=_("Top row layout:")), top_row_layout, PREFERENCES_LEFT))
+
     vbox = Gtk.VBox(False, 2)
     vbox.pack_start(row00, False, False, 0)
     vbox.pack_start(row0, False, False, 0)
@@ -393,13 +398,14 @@ def _view_prefs_panel():
     vbox.pack_start(row7, False, False, 0)
     # Feb-2017 - SvdB - For full file names
     vbox.pack_start(row6, False, False, 0)
+    vbox.pack_start(row8, False, False, 0)
     vbox.pack_start(Gtk.Label(), True, True, 0)
 
     guiutils.set_margins(vbox, 12, 0, 12, 12)
 
     # Feb-2017 - SvdB - Added code for full file names
     return vbox, (force_english_check, display_splash_check, buttons_combo, dark_combo, theme_combo, audio_levels_combo, 
-                  window_mode_combo, show_full_file_names, tracks_combo)
+                  window_mode_combo, show_full_file_names, tracks_combo, top_row_layout)
 
 def _performance_panel():
     # Jan-2017 - SvdB
@@ -441,44 +447,6 @@ def _performance_panel():
 
     return vbox, (perf_render_threads, perf_drop_frames)
 
-"""
-def _shortcuts_panel():
-    # Apr-2017 - SvdB
-    # Add a panel for keyboard shortcuts
-    # Widgets
-    shortcuts_combo = guicomponents.get_shorcuts_selector()
-    
-
-    shortcuts_combo = Gtk.ComboBoxText()
-    current_pref_index = -1
-
-    for i in range(0, len(shortcuts.shortcut_files)):
-        shortcut_file = shortcuts.shortcut_files[i]
-        shortcuts_combo.append_text(shortcuts.shortcut_files_display_names[i])
-        if editorpersistance.prefs.shortcuts == shortcut_file:
-            current_pref_index = i
-    
-    # Set current selection active
-    if current_pref_index != -1:
-        shortcuts_combo.set_active(current_pref_index)
-    else:
-        # Something is wrong, the pref shortcut file is not preset in the system.
-        print "Shortcut file in editprpersistance.pref.shortcuts not found!"
-        shortcuts_combo.set_active(0)
-
-    
-    # Layout
-    row1 = _row(guiutils.get_two_column_box(Gtk.Label(label=_("Shortcuts File")), shortcuts_combo, PREFERENCES_LEFT))
-
-    vbox = Gtk.VBox(False, 2)
-    vbox.pack_start(row1, False, False, 0)
-    vbox.pack_start(Gtk.Label(), True, True, 0)
-
-    guiutils.set_margins(vbox, 12, 0, 12, 12)
-
-    return vbox, (shortcuts_combo)
-"""
-
 def _row(row_cont):
     row_cont.set_size_request(10, 26)
     return row_cont
