@@ -51,13 +51,14 @@ import gui
 import guicomponents
 import guiutils
 import edit
-import editevent
 import editorstate
 from editorstate import current_sequence
 from editorstate import current_bin
 from editorstate import PROJECT
 from editorstate import MONITOR_MEDIA_FILE
+from editorstate import EDIT_MODE
 import editorpersistance
+import kftoolmode
 import medialinker
 import movemodes
 import mltprofiles
@@ -75,6 +76,10 @@ import undo
 import updater
 import utils
 
+media_panel_popup_menu = Gtk.Menu()
+bin_popup_menu = Gtk.Menu()
+sequence_popup_menu = Gtk.Menu()
+hamburger_popup_menu = Gtk.Menu()
 
 save_time = None
 save_icon_remove_event_id = None
@@ -83,7 +88,9 @@ save_icon_remove_event_id = None
 force_overwrite = False
 force_proxy = False
 
-#_xml_render_player = None
+# This is needed to pass only one event for double click, double init for monitor click possibly somewhat unstable
+_media_panel_double_click_counter = 0
+
 
 #--------------------------------------- worker threads
 class LoadThread(threading.Thread):
@@ -119,7 +126,7 @@ class LoadThread(threading.Thread):
             self._error_stop(dialog, ticker)
             Gdk.threads_enter()
             primary_txt = _("Media asset was missing!")
-            secondary_txt = _("Path of missing asset:") + "\n   <b>" + e.value  + "</b>\n\n" + \
+            secondary_txt = _("Path of missing asset:") + "\n   <b>" + e.value.decode('utf-8') + "</b>\n\n" + \
                             _("Relative search for replacement file in sub folders of project file failed.") + "\n\n" + \
                             _("To load the project you will need to either:") + "\n" + \
                             u"\u2022" + " " + _("Open project in 'Media Relinker' tool to relink media assets to new files, or") + "\n" + \
@@ -143,7 +150,7 @@ class LoadThread(threading.Thread):
             return
         except persistance.ProjectProfileNotFoundError as e:
             self._error_stop(dialog, ticker)
-            primary_txt = _("Profile with Description: '") + e.value + _("' was not found on load!")
+            primary_txt = _("Profile with Description: '") + e.value.decode('utf-8')  + _("' was not found on load!")
             secondary_txt = _("It is possible to load the project by creating a User Profile with exactly the same Description\nas the missing profile. ") + "\n\n" + \
                             _("User Profiles can be created by selecting 'Edit->Profiles Manager'.")
             dialogutils.warning_message(primary_txt, secondary_txt, None, is_info=False)
@@ -171,6 +178,7 @@ class LoadThread(threading.Thread):
             render.set_saved_gui_selections(selections)
         updater.set_info_icon(None)
         dialog.destroy()
+        gui.tline_canvas.connect_mouse_events() # mouse events dutring load cause crashes because there is no data to handle
         Gdk.threads_leave()
 
         ticker.stop_ticker()
@@ -238,6 +246,7 @@ class AddMediaFilesThread(threading.Thread):
 
         normal_cursor = Gdk.Cursor.new(Gdk.CursorType.LEFT_PTR) #RTL
         gui.editor_window.window.get_window().set_cursor(normal_cursor)
+        gui.editor_window.bin_info.display_bin_info()
         Gdk.threads_leave()
 
         if len(duplicates) > 0:
@@ -317,6 +326,8 @@ def _not_matching_media_info_callback(dialog, response_id, media_file):
     profile = mltprofiles.get_profile_for_index(match_profile_index)
         
     if response_id == Gtk.ResponseType.ACCEPT:
+        if EDIT_MODE() == editorstate.KF_TOOL:
+            kftoolmode.exit_tool()
         # Save in hidden and open
         match_profile_index = mltprofiles.get_closest_matching_profile_index(media_file.info)
         profile = mltprofiles.get_profile_for_index(match_profile_index)
@@ -385,13 +396,14 @@ def _close_dialog_callback(dialog, response_id):
         return
         
     # This is the same as opening default project
-    sequence.AUDIO_TRACKS_COUNT = 4
-    sequence.VIDEO_TRACKS_COUNT = 5
+    sequence.AUDIO_TRACKS_COUNT = appconsts.INIT_A_TRACKS
+    sequence.VIDEO_TRACKS_COUNT = appconsts.INIT_V_TRACKS
 
     new_project = projectdata.get_default_project()
     app.open_project(new_project)
     
 def actually_load_project(filename, block_recent_files=False):
+    gui.tline_canvas.disconnect_mouse_events() # mouse events dutring load cause crashes because there is no data to handle
     load_launch = LoadThread(filename, block_recent_files)
     load_launch.start()
 
@@ -486,7 +498,7 @@ def save_backup_snapshot():
     name = parts[0] + datetime.datetime.now().strftime("-%y%m%d") + ".flb"
     dialogs.save_backup_snapshot(name, _save_backup_snapshot_dialog_callback)
 
-def _save_backup_snapshot_dialog_callback(dialog, response_id, project_folder, name_entry):  
+def _save_backup_snapshot_dialog_callback(dialog, response_id, project_folder, name_entry):
     if response_id == Gtk.ResponseType.ACCEPT:
 
         root_path = project_folder.get_filenames()[0]
@@ -497,10 +509,10 @@ def _save_backup_snapshot_dialog_callback(dialog, response_id, project_folder, n
             dialogutils.info_message(primary_txt, secondary_txt, gui.editor_window.window)
             return
 
-        name = name_entry.get_text()
+        name = name_entry.get_text().decode('utf-8')
         dialog.destroy()
         
-        GLib.idle_add(lambda : _do_snapshot_save(root_path + "/", name))
+        GLib.idle_add(lambda : _do_snapshot_save(root_path.decode('utf-8') + "/", name))
 
     else:
         dialog.destroy()
@@ -523,7 +535,7 @@ def _change_project_profile_callback(dialog, response_id, profile_combo, out_fol
         folder = (u"/" + ou.lstrip(u"file:/"))
         name = project_name_entry.get_text().decode('utf-8')
         profile = mltprofiles.get_profile_for_index(profile_combo.get_active())
-        path = folder + u"/" + name
+        path = (folder + u"/" + name).encode('utf-8')
 
         PROJECT().update_media_lengths_on_load = True # saved version needs to do this
         old_name = PROJECT().name
@@ -571,15 +583,18 @@ class SnaphotSaveThread(threading.Thread):
             
             # Message
             Gdk.threads_enter()
-            dialog.media_copy_info.set_text(copy_txt + "... " +  file_name)
+            dialog.media_copy_info.set_text(copy_txt + "... " +  file_name.decode('utf-8'))
             Gdk.threads_leave()
             
             # Other media types than image sequences
             if media_file.type != appconsts.IMAGE_SEQUENCE:
-                media_file_copy = media_folder + file_name
+                media_file_copy = media_folder + file_name.decode('utf-8')
+
+                # TEST THIS SOMEHOW FOR UNICODE PROBLEMS
                 if media_file_copy in asset_paths.values(): # Create different filename for files 
                                                              # that have same basename but different path
                     file_name = get_snapshot_unique_name(media_file.path, file_name)
+
                     media_file_copy = media_folder + file_name
                     
                 shutil.copyfile(media_file.path, media_file_copy)
@@ -610,7 +625,8 @@ class SnaphotSaveThread(threading.Thread):
                     # Only producer clips are affected
                     if (clip.is_blanck_clip == False and (clip.media_type != appconsts.PATTERN_PRODUCER)):
                         directory, file_name = os.path.split(clip.path)
-                        clip_file_copy = media_folder + file_name
+                        clip_file_copy = media_folder + file_name.decode('utf-8')
+                        
                         if not os.path.isfile(clip_file_copy):
                             directory, file_name = os.path.split(clip.path)
                             Gdk.threads_enter()
@@ -627,7 +643,7 @@ class SnaphotSaveThread(threading.Thread):
         Gdk.threads_enter()
         dialog.media_copy_info.set_text(copy_txt + "    " +  u"\u2713")
         Gdk.threads_leave()
-        
+
         save_path = self.root_folder_path + self.project_name
 
         persistance.snapshot_paths = asset_paths
@@ -701,7 +717,7 @@ def _open_recent_shutdown_dialog_callback(dialog, response_id, path):
 
 def _actually_open_recent(path):
     if not os.path.exists(path):
-        editorpersistance.recent_projects.projects.pop(index)
+        editorpersistance.remove_non_existing_recent_projects()
         editorpersistance.fill_recents_menu_widget(gui.editor_window.uimanager.get_widget('/MenuBar/FileMenu/OpenRecent'), open_recent_project)
         primary_txt = _("Project not found on disk")
         secondary_txt = _("Project can't be loaded.")
@@ -836,6 +852,80 @@ def _write_out_render_item(single_render_item_item):
     return True
 
 # ----------------------------------- media files
+def hamburger_pressed(widget, event):
+    hamburger_menu = hamburger_popup_menu
+    
+    guiutils.remove_children(hamburger_menu)
+
+    hamburger_menu.add(guiutils.get_menu_item(_("Render Proxy Files For Selected Media"), _hamburger_menu_item_selected, "render proxies", ))
+    guiutils.add_separetor(hamburger_menu)
+    hamburger_menu.add(guiutils.get_menu_item(_("Select All"), _hamburger_menu_item_selected, "select all"))
+    hamburger_menu.add(guiutils.get_menu_item(_("Select None"), _hamburger_menu_item_selected, "select none"))
+
+    move_menu_item = Gtk.MenuItem(_("Move Selected Media To Bin").encode('utf-8'))
+    move_menu = Gtk.Menu()
+    if len(PROJECT().bins) == 1:
+        item = guiutils.get_menu_item(_("No Target Bins"), _hamburger_menu_item_selected, "dummy")
+        item.set_sensitive(False)
+        move_menu.add(item)
+    else:
+        index = 0
+        for media_bin in PROJECT().bins:
+            if media_bin == PROJECT().c_bin:
+                index = index + 1
+                continue
+            name = media_bin
+            item = guiutils.get_menu_item(media_bin.name, _hamburger_menu_item_selected, str(index))
+            move_menu.add(item)
+            item.show()
+            index = index + 1
+    move_menu_item.set_submenu(move_menu)
+    hamburger_menu.add(move_menu_item)
+    move_menu_item.show()
+    
+    hamburger_menu.popup(None, None, None, None, event.button, event.time)
+
+
+def _hamburger_menu_item_selected(widget, msg):
+    if msg == "render proxies":
+        proxyediting.create_proxy_files_pressed()
+    elif msg == "select all":
+        gui.media_list_view.select_all()
+    elif msg == "select none":
+        gui.media_list_view.clear_selection()
+    else:
+        target_bin_index = int(msg)
+        
+        media_bin_indexes = []
+        for selected_object in gui.media_list_view.selected_objects:
+            media_bin_indexes.append(selected_object.bin_index)
+        
+        move_files_to_bin(target_bin_index, media_bin_indexes)
+        #print target_bin_inxdex, media_bin_indexes
+
+def media_panel_popup_requested(event):
+    panel_menu = media_panel_popup_menu
+    
+    guiutils.remove_children(panel_menu)
+
+    panel_menu.add(guiutils.get_menu_item(_("Add Video, Audio or Image..."), _media_panel_menu_item_selected, "add media", ))
+    panel_menu.add(guiutils.get_menu_item(_("Add Image Sequence..."), _media_panel_menu_item_selected, "add image sequence"))
+    
+    panel_menu.popup(None, None, None, None, event.button, event.time)
+
+def _media_panel_menu_item_selected(widget, msg):
+    if msg == "add media":
+        add_media_files()
+    elif msg == "add image sequence":
+        add_image_sequence()
+
+def media_panel_double_click(media_file):
+    global _media_panel_double_click_counter
+    _media_panel_double_click_counter += 1
+    if _media_panel_double_click_counter == 2:
+        _media_panel_double_click_counter = 0
+        updater.set_and_display_monitor_media_file(media_file)
+            
 def add_media_files(this_call_is_retry=False):
     """
     User selects a media file to added to current bin.
@@ -1016,14 +1106,14 @@ def delete_media_files(force_delete=False):
     for i in bin_indexes:
         current_bin().file_ids.pop(i)
     update_current_bin_files_count()
-        
+    
     # Delete from project
     for file_id in file_ids:
         PROJECT().media_files.pop(file_id)
 
     gui.media_list_view.fill_data_model()
-
     _enable_save()
+    gui.editor_window.bin_info.display_bin_info()
 
 def _proxy_delete_warning_callback(dialog, response_id):
     dialog.destroy()
@@ -1096,7 +1186,7 @@ def _display_file_info(media_file):
     try:
         num = info["fps_num"]
         den = info["fps_den"]
-        fps = float(num/den) 
+        fps = utils.get_fps_str_with_two_decimals(str(float(num/den)))
     except:
         fps = _("N/A")
     
@@ -1234,6 +1324,63 @@ def _get_compound_clip_default_name_date_str():
 
 
 # ------------------------------------ bins
+def bins_panel_popup_requested(event):
+    bin_menu = bin_popup_menu
+    
+    guiutils.remove_children(bin_menu)
+
+    bin_menu.add(guiutils.get_menu_item(_("Add Bin"), _bin_menu_item_selected, ("add bin", None)))
+    bin_menu.add(guiutils.get_menu_item(_("Delete Selected Bin"), _bin_menu_item_selected, ("delete bin", None)))
+
+    guiutils.add_separetor(bin_menu)
+    
+    move_menu_item = Gtk.MenuItem(_("Move Bin").encode('utf-8'))
+    move_menu = Gtk.Menu()
+    move_menu.add(guiutils.get_menu_item(_("Up"), _bin_menu_item_selected, ("up bin", None)))
+    move_menu.add(guiutils.get_menu_item(_("Down"), _bin_menu_item_selected, ("down bin", None)))
+    move_menu.add(guiutils.get_menu_item(_("First"), _bin_menu_item_selected, ("first bin", None)))
+    move_menu.add(guiutils.get_menu_item(_("Last"), _bin_menu_item_selected, ("last bin", None)))
+    move_menu_item.set_submenu(move_menu)
+    bin_menu.add(move_menu_item)
+    move_menu_item.show()
+    
+    bin_menu.popup(None, None, None, None, event.button, event.time)    
+
+def _bin_menu_item_selected(widget, data):
+    msg, bin_obj = data
+    if msg == "add bin":
+        add_new_bin()
+    elif msg == "delete bin":
+        delete_selected_bin()
+    elif msg == "up bin":
+        c_index = PROJECT().bins.index(PROJECT().c_bin)
+        if c_index == 0 or len(PROJECT().bins) == 1:
+            return
+        _move_bin(c_index, c_index - 1)
+    elif msg == "down bin":
+        c_index = PROJECT().bins.index(PROJECT().c_bin)
+        if c_index >= len(PROJECT().bins) - 1:
+            return # already last
+        _move_bin(c_index, c_index + 1)
+    elif msg == "first bin":
+        c_index = PROJECT().bins.index(PROJECT().c_bin)
+        if c_index == 0 or len(PROJECT().bins) == 1:
+            return
+        _move_bin(c_index, 0)
+    elif msg == "last bin":
+        c_index = PROJECT().bins.index(PROJECT().c_bin)
+        if c_index >= len(PROJECT().bins) - 1:
+            return # already last
+        _move_bin(c_index, len(PROJECT().bins) - 1)
+
+def _move_bin(pop_index, insert_index):
+    PROJECT().bins.pop(pop_index)
+    PROJECT().bins.insert(insert_index, PROJECT().c_bin)
+    gui.bin_list_view.fill_data_model()
+    selection = gui.bin_list_view.treeview.get_selection()
+    model, iterator = selection.get_selected()
+    selection.select_path(str(insert_index))
+    
 def add_new_bin():
     """
     Adds new unnamed bin and sets it selected 
@@ -1244,6 +1391,7 @@ def add_new_bin():
     model, iterator = selection.get_selected()
     selection.select_path(str(len(model)-1))
     _enable_save()
+    gui.editor_window.bin_info.display_bin_info()
 
 def delete_selected_bin():
     """
@@ -1273,6 +1421,7 @@ def delete_selected_bin():
     # Set first bin selected, listener 'bin_selection_changed' updates editorstate.project.c_bin
     selection.select_path("0")
     _enable_save()
+    gui.editor_window.bin_info.display_bin_info()
                   
 def bin_name_edited(cell, path, new_text, user_data):
     """
@@ -1282,10 +1431,13 @@ def bin_name_edited(cell, path, new_text, user_data):
     if len(new_text) == 0:
         return
     
+    new_text = new_text.decode('utf-8')
+    
     liststore, column = user_data
     liststore[path][column] = new_text
     PROJECT().bins[int(path)].name = new_text
     _enable_save()
+    gui.editor_window.bin_info.display_bin_info()
 
 def update_current_bin_files_count():
     # Get index for selected bin
@@ -1317,6 +1469,7 @@ def bin_selection_changed(selection):
     # Set current and display
     PROJECT().c_bin = PROJECT().bins[row]
     gui.media_list_view.fill_data_model()
+    gui.editor_window.bin_info.display_bin_info()
     
 def move_files_to_bin(new_bin, bin_indexes):
     # If we're moving clips to bin that they're already in, do nothing.
@@ -1337,6 +1490,13 @@ def move_files_to_bin(new_bin, bin_indexes):
     gui.media_list_view.fill_data_model()
     gui.bin_list_view.fill_data_model()
 
+    # We need to select current gin again to show it selected in GUI
+    selection = gui.bin_list_view.treeview.get_selection()
+    model, iterator = selection.get_selected()
+    c_bin_index = PROJECT().bins.index(PROJECT().c_bin)
+    selection.select_path(str(c_bin_index))
+    
+    gui.editor_window.bin_info.display_bin_info()
     
     
 # ------------------------------------ sequences
@@ -1356,6 +1516,26 @@ def change_edit_sequence():
     
     app.change_current_sequence(row)
 
+def sequence_panel_popup_requested(event):
+    sequence_menu = sequence_popup_menu
+    
+    guiutils.remove_children(sequence_menu)
+
+    sequence_menu.add(guiutils.get_menu_item(_("Add New Sequence"), _sequece_menu_item_selected, ("add sequence", None)))
+    sequence_menu.add(guiutils.get_menu_item(_("Edit Selected Sequence"), _sequece_menu_item_selected, ("edit sequence", None)))
+    sequence_menu.add(guiutils.get_menu_item(_("Delete Selected Sequence"), _sequece_menu_item_selected, ("delete sequence", None)))
+    
+    sequence_menu.popup(None, None, None, None, event.button, event.time)    
+
+def _sequece_menu_item_selected(widget, data):
+    msg, bin_obj = data
+    if msg == "add sequence":
+        add_new_sequence()
+    elif msg == "delete sequence":
+        delete_selected_sequence()
+    elif msg == "edit sequence":
+        change_edit_sequence()
+
 def add_new_sequence():
     default_name = _("sequence_") + str(PROJECT().next_seq_number)
     dialogs.new_sequence_dialog(_add_new_sequence_dialog_callback, default_name)
@@ -1371,10 +1551,10 @@ def _add_new_sequence_dialog_callback(dialog, response_id, widgets):
     name_entry, tracks_select, open_check = widgets
     
     # Get dialog data 
-    name = name_entry.get_text()
-
+    name = name_entry.get_text().decode('utf-8')
     if len(name) == 0:
-        name = _("sequence_") + str(PROJECT().next_seq_number)
+        name = (_("sequence_") + str(PROJECT().next_seq_number)).decode('utf-8')
+
     v_tracks, a_tracks = tracks_select.get_tracks()
     open_right_away = open_check.get_active()
     
@@ -1411,6 +1591,17 @@ def delete_selected_sequence():
                                  _("This operation can not be undone. Sequence will be permanently lost."), 
                                  gui.editor_window.window)
 
+def sequence_list_double_click_done():
+    selection = gui.sequence_list_view.treeview.get_selection()
+    model, iter = selection.get_selected()
+    (model, rows) = selection.get_selected_rows()
+    row = max(rows[0])
+    
+    c_seq_index = PROJECT().sequences.index(PROJECT().c_seq)
+    
+    if c_seq_index != row:
+        change_edit_sequence()
+
 def _delete_confirm_callback(dialog, response_id):
     if response_id != Gtk.ResponseType.ACCEPT:
         dialog.destroy()
@@ -1450,6 +1641,8 @@ def sequence_name_edited(cell, path, new_text, user_data):
     if len(new_text) == 0:
         return
 
+    new_text = new_text.decode('utf-8')
+
     liststore, column = user_data
     liststore[path][column] = new_text
     PROJECT().sequences[int(path)].name = new_text
@@ -1457,7 +1650,8 @@ def sequence_name_edited(cell, path, new_text, user_data):
     _enable_save()
 
 def change_sequence_track_count():
-    dialogs.tracks_count_change_dialog(_change_track_count_dialog_callback)
+    nv, na = PROJECT().c_seq.get_track_counts()
+    dialogs.tracks_count_change_dialog(_change_track_count_dialog_callback, nv, na)
 
 def _change_track_count_dialog_callback(dialog, response_id, tracks_select):
     if response_id != Gtk.ResponseType.ACCEPT:
