@@ -24,16 +24,19 @@ Module creates GUI editors for editable mlt properties.
 
 from gi.repository import Gtk, Gdk, GObject
 
+import cairo
+
 import appconsts
+import cairoarea
 from editorstate import PROJECT
 from editorstate import PLAYER
-from editorstate import current_sequence
 import extraeditors
 import guiutils
 import keyframeeditor
 import mltfilters
 import mlttransitions
 import propertyparse
+import respaths
 import translations
 import updater
 import utils
@@ -60,8 +63,10 @@ CR_CURVES = "crcurves"                                      # Curves color edito
 COLOR_BOX = "colorbox"                                      # One band color editor with color box interface
 COLOR_LGG = "colorlgg"                                      # Editor for ColorLGG filter
 FILE_SELECTOR = "file_select"                               # File selector button for selecting single files from
+IMAGE_MEDIA_FILE_SELECTOR = "image_media_file_select"       # File selector button for selecting single files from
 FILE_TYPES = "file_types"                                   # list of files types with "." chracters, like ".png.tga.bmp"
-FADE_LENGTH = "fade_length"                                 # Autofade composiyots fade length
+FADE_LENGTH = "fade_length"                                 # Autofade compositors fade length
+TEXT_ENTRY = "text_entry"                                   # Text editor
 NO_EDITOR = "no_editor"                                     # No editor displayed for property
 
 COMPOSITE_EDITOR_BUILDER = "composite_properties"           # Creates a single row editor for multiple properties of composite transition
@@ -70,6 +75,12 @@ ROTATION_GEOMETRY_EDITOR_BUILDER = "rotation_geometry_editor" # Creates a single
 
 SCALE_DIGITS = "scale_digits"                               # Number of decimal digits displayed in a widget
 
+# We need to use globals to change slider -> kf editor and back because the data does not (can not) exist anywhere else. FilterObject.properties are just tuples and EditableProperty objects
+# are created deterministically from those and FilterObject.info.property_args data. So we need to save data here on change request to make the change happen.
+# This data needs to be erased always after use.
+changing_slider_to_kf_property_name = None
+re_init_editors_for_slider_type_change_func = None # monkeypatched in, it is clipeffectseditor.effect_selection_changed
+
 def _p(name):
     try:
         return translations.param_names[name]
@@ -137,40 +148,156 @@ def _get_two_column_editor_row(name, editor_widget):
     return hbox
     
 def _get_slider_row(editable_property, slider_name=None, compact=False):
-    adjustment = editable_property.get_input_range_adjustment()
-    adjustment.connect("value-changed", editable_property.adjustment_value_changed)
+    slider_editor = SliderEditor(editable_property, slider_name=None, compact=False)
 
-    hslider = Gtk.HScale()
-    hslider.set_adjustment(adjustment)
-    hslider.set_draw_value(False)
-
-    spin = Gtk.SpinButton()
-    spin.set_numeric(True)
-    spin.set_adjustment(adjustment)
-
-    _set_digits(editable_property, hslider, spin)
-
-    if slider_name == None:
-        name = editable_property.get_display_name()
-    else:
-        name = slider_name
-    name = _p(name)
+    # We need to tag this somehow and add lambda to pass frame events so that this can be to set get frame events
+    # in clipeffectseditor.py.
+    if slider_editor.editor_type == KEYFRAME_EDITOR:
+        slider_editor.vbox.is_kf_editor = True      
+        slider_editor.vbox.display_tline_frame = lambda tline_frame:slider_editor.kfeditor.display_tline_frame(tline_frame)
+        
+    return slider_editor.vbox
     
-    hbox = Gtk.HBox(False, 4)
-    if compact:
-        name_label = Gtk.Label(label=name + ":")
-        hbox.pack_start(name_label, False, False, 4)
-    hbox.pack_start(hslider, True, True, 0)
-    hbox.pack_start(spin, False, False, 4)
 
-    vbox = Gtk.VBox(False)
-    if compact:
-        vbox.pack_start(hbox, False, False, 0)
-    else:
-        top_row = _get_two_column_editor_row(name, Gtk.HBox())
-        vbox.pack_start(top_row, True, True, 0)
-        vbox.pack_start(hbox, False, False, 0)
-    return vbox
+class SliderEditor:
+    def __init__(self, editable_property, slider_name=None, compact=False):
+
+        self.vbox = Gtk.VBox(False)
+        # We are using value here as flag if this is beinfg edited by slider as a single value or by keyframe editor as changing value
+        # If we find "=" this means that value is keyframe expression
+        is_multi_kf = (editable_property.value.find("=") != -1)
+
+        if changing_slider_to_kf_property_name == editable_property.name or is_multi_kf == True:
+            eq_index = editable_property.value.find("=")
+            
+            # create kf in frame 0 if value PROP_INT or PROP_FLOAT
+            if eq_index == -1:
+                new_value = "0=" + editable_property.value
+                editable_property.value = new_value
+                editable_property.write_filter_object_property(new_value)
+                            
+            editable_property = editable_property.get_as_KeyFrameHCSFilterProperty()
+            self.init_for_kf_editor(editable_property)
+            
+            # This has now already been used if existed and has to be deleted.
+            if changing_slider_to_kf_property_name == editable_property.name:
+                global changing_slider_to_kf_property_name
+                changing_slider_to_kf_property_name = None
+        else:
+            self.init_for_slider(editable_property, slider_name, compact)
+        
+        self.editable_property = editable_property
+        
+    def init_for_slider(self, editable_property, slider_name=None, compact=False):
+        self.editor_type = SLIDER
+        
+        adjustment = editable_property.get_input_range_adjustment()
+        adjustment.connect("value-changed", editable_property.adjustment_value_changed)
+
+        hslider = Gtk.HScale()
+        hslider.set_adjustment(adjustment)
+        hslider.set_draw_value(False)
+
+        spin = Gtk.SpinButton()
+        spin.set_numeric(True)
+        spin.set_adjustment(adjustment)
+
+        _set_digits(editable_property, hslider, spin)
+
+        if slider_name == None:
+            name = editable_property.get_display_name()
+        else:
+            name = slider_name
+        name = _p(name)
+        
+        kfs_switcher = KeyframesToggler(self)
+                
+        hbox = Gtk.HBox(False, 4)
+        if compact:
+            name_label = Gtk.Label(label=name + ":")
+            hbox.pack_start(name_label, False, False, 4)
+        hbox.pack_start(hslider, True, True, 0)
+        hbox.pack_start(spin, False, False, 4)
+        hbox.pack_start(kfs_switcher.widget, False, False, 4)
+
+        if compact:
+            self.vbox.pack_start(hbox, False, False, 0)
+        else:
+            top_right_h = Gtk.HBox()
+            top_right_h.pack_start(Gtk.Label(), True, True, 0)            
+            top_row = _get_two_column_editor_row(name, top_right_h)
+            
+            self.vbox.pack_start(top_row, True, True, 0)
+            self.vbox.pack_start(hbox, False, False, 0)
+
+    def init_for_kf_editor(self, editable_property):
+        self.editor_type = KEYFRAME_EDITOR
+        
+        kfs_switcher = KeyframesToggler(self)
+        self.kfeditor = keyframeeditor.KeyFrameEditor(editable_property, True, kfs_switcher)
+        self.vbox.pack_start(self.kfeditor, False, False, 0)
+
+    def kfs_toggled(self):
+        if self.editor_type == SLIDER: # slider -> kf editor
+            global changing_slider_to_kf_property_name
+            changing_slider_to_kf_property_name = self.editable_property.name
+            re_init_editors_for_slider_type_change_func()
+        else: # kf editor -> slider
+            # Save value as single keyframe or PROP_INT or PROP_FLOAT and
+            # drop all but first keyframe.
+            # Going kf editor -> slider destroys all but first keyframe.
+            first_kf_index = self.editable_property.value.find(";")
+            if first_kf_index == -1:
+                val = self.editable_property.value
+            else:
+                val = self.editable_property.value[0:first_kf_index]
+            
+            eq_index = self.editable_property.value.find("=")  + 1
+            first_kf_val = val[eq_index:len(val)]
+
+            #  We need to turn editable property value and type  back to what it was before user selected to go kf editing
+            # so that it gets edited with slider on next init.
+            info = self.editable_property._get_filter_object().info #.__dict__
+            p_name, p_value, p_original_type = info.properties[self.editable_property.property_index]
+            
+            if p_original_type == appconsts.PROP_INT:
+                self.editable_property.type = appconsts.PROP_INT
+                int_str_val = str(int(first_kf_val))
+                self.editable_property.write_filter_object_property(int_str_val)
+                self.editable_property.value = str(int(first_kf_val))
+            elif p_original_type == appconsts.PROP_FLOAT:
+                self.editable_property.type = appconsts.PROP_FLOAT 
+                self.editable_property.write_filter_object_property(str(float(first_kf_val)))
+                self.editable_property.value = str(float(first_kf_val))
+            else:
+                self.editable_property.write_filter_object_property("0=" + str(float(first_kf_val)))
+
+            re_init_editors_for_slider_type_change_func()
+
+
+class KeyframesToggler:
+    def __init__(self, parent_editor):
+        w=16
+        h=22
+        self.widget = cairoarea.CairoDrawableArea2( w,
+                                                    h,
+                                                    self._draw)
+        self.widget.press_func = self._press_event
+        self.parent_editor = parent_editor
+        if parent_editor.editor_type == KEYFRAME_EDITOR:
+            self.surface  = cairo.ImageSurface.create_from_png(respaths.IMAGE_PATH + "slider_icon.png")
+        else:
+            self.surface  = cairo.ImageSurface.create_from_png(respaths.IMAGE_PATH + "kf_active.png")
+
+        self.surface_x  = 3
+        self.surface_y  = 8
+
+    def _draw(self, event, cr, allocation):
+        cr.set_source_surface(self.surface, self.surface_x, self.surface_y)
+        cr.paint()
+
+    def _press_event(self, event):
+        self.parent_editor.kfs_toggled()
 
 def _get_ladspa_slider_row(editable_property, slider_name=None):
     adjustment = editable_property.get_input_range_adjustment()
@@ -323,7 +450,23 @@ def _get_affine_slider(name, adjustment):
     hbox.pack_start(spin, False, False, 4)
 
     return (hslider, spin, _get_two_column_editor_row(name, hbox))
-    
+
+
+def _get_text_entry(editable_property):
+    entry = Gtk.Entry.new()
+    entry.set_text(editable_property.value)
+    entry.connect("changed", lambda w: _entry_contentents_changed(w, editable_property))
+
+    hbox = Gtk.HBox(False, 4)
+    hbox.pack_start(entry, True, True, 0)
+    #hbox.pack_start(Gtk.Label(), False, False, 4)
+
+
+    return _get_two_column_editor_row(editable_property.get_display_name(), hbox)
+
+def _entry_contentents_changed(entry, editable_property):
+     editable_property.value = entry.get_text()
+ 
 def _get_boolean_check_box_row(editable_property):
     check_button = Gtk.CheckButton()
     check_button.set_active(editable_property.value == "1")
@@ -441,7 +584,7 @@ def _get_wipe_selector(editable_property):
     
     combo_box.connect("changed", editable_property.combo_selection_changed, keys)
     use_preset_luma_combo.connect("changed", _wipe_preset_combo_changed, editable_property, widgets)
-    dialog.connect('response', _wipe_lumafile_dialog_response, editable_property, widgets)
+    user_luma_select.connect('file-set', _wipe_lumafile_dialog_response, editable_property, widgets)
     
     return editor_pane
 
@@ -483,7 +626,7 @@ class FadeLengthEditor(Gtk.HBox):
         updater.repaint_tline()
     
     def display_tline_frame(self, frame):
-        pass # we don't seem to need this afte all, panel gets recreated after cpompositor length change
+        pass # we don't seem to need this after all, panel gets recreated after compositor length change
         
 def _get_fade_length_editor(editable_property):
     return FadeLengthEditor(editable_property)
@@ -503,15 +646,18 @@ def _wipe_preset_combo_changed(widget, ep, widgets):
         combo_box.set_sensitive(True)
         ep.combo_selection_changed(combo_box, keys)
 
-def _wipe_lumafile_dialog_response(dialog, response_id, ep, widgets):
+def _wipe_lumafile_dialog_response(button, ep, widgets):
     combo_box, use_preset_luma_combo, user_luma_select, user_luma_label, keys = widgets
     file_name = user_luma_select.get_filename()
+
     if file_name != None:
+        ep.combo_selection_changed(combo_box, keys)
         ep.write_value(file_name)
 
+
 def _get_file_select_editor(editable_property):
     """
-    Returns GUI component for selecting wipe type.
+    Returns GUI component for selecting file of determined type
     """
     dialog = Gtk.FileChooserDialog(_("Select File"), None, 
                                    Gtk.FileChooserAction.OPEN, 
@@ -543,6 +689,34 @@ def _get_file_select_editor(editable_property):
     
     return editor_row
     
+def _get_image_file_select_editor(editable_property):
+    """
+    Returns GUI component for selecting image producing file
+    """
+    dialog = Gtk.FileChooserDialog(_("Select Image Producing File"), None, 
+                                   Gtk.FileChooserAction.OPEN, 
+                                   (_("Cancel").encode('utf-8'), Gtk.ResponseType.CANCEL,
+                                    _("OK").encode('utf-8'), Gtk.ResponseType.ACCEPT))
+    dialog.set_action(Gtk.FileChooserAction.OPEN)
+    dialog.set_select_multiple(False)
+
+    file_filter = utils.get_media_source_file_filter(False)    
+    dialog.add_filter(file_filter)
+        
+    file_select_button = Gtk.FileChooserButton.new_with_dialog(dialog)
+    file_select_button.set_size_request(210, 28)
+    
+    file_select_label = Gtk.Label(editable_property.get_display_name())
+
+    editor_row = Gtk.HBox(False, 2)
+    editor_row.pack_start(file_select_label, False, False, 2)
+    editor_row.pack_start(guiutils.get_pad_label(3, 5), False, False, 2)
+    editor_row.pack_start(file_select_button, False, False, 0)
+
+    dialog.connect('response', editable_property.dialog_response_callback)
+    
+    return editor_row
+    
 def _create_composite_editor(clip, editable_properties):
     aligned = filter(lambda ep: ep.name == "aligned", editable_properties)[0]
     distort = filter(lambda ep: ep.name == "distort", editable_properties)[0]
@@ -772,6 +946,7 @@ EDITOR_ROW_CREATORS = { \
     LADSPA_SLIDER: lambda ep: _get_ladspa_slider_row(ep),
     CLIP_FRAME_SLIDER: lambda ep: _get_clip_frame_slider(ep),
     FILE_SELECTOR: lambda ep: _get_file_select_editor(ep),
+    IMAGE_MEDIA_FILE_SELECTOR: lambda ep: _get_image_file_select_editor(ep),
     FADE_LENGTH: lambda ep: _get_fade_length_editor(ep),
     NO_EDITOR: lambda ep: _get_no_editor(),
     COMPOSITE_EDITOR_BUILDER: lambda comp, editable_properties: _create_composite_editor(comp, editable_properties),
@@ -780,7 +955,8 @@ EDITOR_ROW_CREATORS = { \
     COLOR_CORRECTOR: lambda filt, editable_properties: _create_color_grader(filt, editable_properties),
     CR_CURVES: lambda filt, editable_properties:_create_crcurves_editor(filt, editable_properties),
     COLOR_BOX: lambda filt, editable_properties:_create_colorbox_editor(filt, editable_properties),
-    COLOR_LGG: lambda filt, editable_properties:_create_color_lgg_editor(filt, editable_properties)
+    COLOR_LGG: lambda filt, editable_properties:_create_color_lgg_editor(filt, editable_properties),
+    TEXT_ENTRY: lambda ep: _get_text_entry(ep),
     }
 
 """
