@@ -43,14 +43,17 @@ PATTERN_PRODUCER_PATH = None
 LAUNCH_DIR = None
 GMIC_SCRIPTS_DOC = None
 PHANTOM_JAR = None
+NATRON_PROJECTS_XML_DOC = None
 
 def set_paths(root_path):
+    # Apr-2017 - SvdB - Added SHORTCUTS_PATH for keyboard shortcuts files
     global ROOT_PATH, IMAGE_PATH, THUMBNAIL_PATH, PROFILE_PATH,\
     BLACK_IMAGE_PATH, FILTERS_XML_DOC, COMPOSITORS_XML_DOC, \
     WIPE_RESOURCES_PATH, PREFS_PATH, HELP_DOC, LOCALE_PATH, \
     GPL_3_DOC, ROOT_PARENT, PATTERN_PRODUCER_PATH, TRANSLATIONS_DOC, \
     LAUNCH_DIR, REPLACEMENTS_XML_DOC, GMIC_SCRIPTS_DOC,  \
-    PHANTOM_JAR, PHANTOM_DIR, DEVELOPERS_DOC, CONTRIBUTORS_DOC
+    PHANTOM_JAR, PHANTOM_DIR, DEVELOPERS_DOC, CONTRIBUTORS_DOC, \
+    SHORTCUTS_PATH, NATRON_PROJECTS_XML_DOC
     
     ROOT_PATH = root_path
     IMAGE_PATH = root_path + "/res/img/"
@@ -72,7 +75,15 @@ def set_paths(root_path):
     LAUNCH_DIR = root_path + "/launch/"
     GMIC_SCRIPTS_DOC = root_path + "/res/gmic/gmicscripts.xml"
     PHANTOM_JAR = root_path + "/phantom2d/Phantom2D.jar"
+    # Apr-2017 - SvdB
+    SHORTCUTS_PATH = root_path + "/res/shortcuts/"
+    NATRON_PROJECTS_XML_DOC = root_path + "/res/natron/natronprojects.xml"
 
 def apply_dark_theme():
     global IMAGE_PATH
     IMAGE_PATH = ROOT_PATH + "/res/darktheme/"
+
+def set_gmic2(root_path):
+    global GMIC_SCRIPTS_DOC
+    GMIC_SCRIPTS_DOC = root_path + "/res/gmic/gmic2scripts.xml"
+    
