@@ -68,8 +68,8 @@ MLT_FILTER = 2
 # NOTE: These are set from other modules (and this one when cloning) when creating or loading projects
 # and used in Sequence.__init__(...) when creating sequences.
 # Weak design, tracks count should be provided via constructor at creation time.
-AUDIO_TRACKS_COUNT = 4
-VIDEO_TRACKS_COUNT = 5
+AUDIO_TRACKS_COUNT = appconsts.INIT_A_TRACKS
+VIDEO_TRACKS_COUNT = appconsts.INIT_V_TRACKS
 
 def set_track_counts(project):
     global AUDIO_TRACKS_COUNT, VIDEO_TRACKS_COUNT
@@ -268,6 +268,12 @@ class Sequence:
         # Tracks may be FREE or LOCKED
         track.edit_freedom = FREE
 
+    def get_track_counts(self):
+        """returns (video track count, audio track count)"""
+        nv = len(self.tracks) - self.first_video_index - 1
+        na = self.first_video_index - 1
+        return (nv, na)
+
     def _mix_audio_for_track(self, track):
         # Create and add transition to combine track audios
         transition = mlt.Transition(self.profile, "mix")
@@ -507,6 +513,15 @@ class Sequence:
         self.next_id += 1
         return self.next_id - 1
 
+    def clip_is_in_sequence(self, test_clip):
+        for i in range(1, len(self.tracks)):
+            track = self.tracks[i]
+            for clip in track.clips:
+                if clip == test_clip:
+                    return True
+        
+        return False
+
     # ------------------------------------------ blanks
     def create_and_insert_blank(self, track, index, length):
         """
@@ -865,10 +880,8 @@ class Sequence:
         Returns frame of next cut in active tracks relative to timeline.
         """
         cut_frame = -1
-        for i in range(1, len(self.tracks)):
+        for i in range(1, len(self.tracks) - 1):
             track = self.tracks[i]
-            if track.active == False:
-                continue
             
             # Get index and clip
             index = track.get_clip_index_at(tline_frame)
@@ -895,10 +908,9 @@ class Sequence:
         Returns frame of next cut in active tracks relative to timeline.
         """
         cut_frame = -1
-        for i in range(1, len(self.tracks)):
+        for i in range(1, len(self.tracks) - 1):
             track = self.tracks[i]
-            if track == False:
-                continue
+            #print track.get_producer().get_length()
             
             # Get index and clip start
             index = track.get_clip_index_at(tline_frame)
@@ -908,21 +920,24 @@ class Sequence:
             if clip_start_frame == tline_frame:
                 index = index - 1
             
-            # Check index is good
-            try:
-                clip = track.clips[index]            
-            except Exception:
-                continue # index not good clip
-            
             # Get prev cut frame
-            next_cut_frame = track.clip_start(index)
+            try:
+                clip = track.clips[index]
+                prev_cut_frame = track.clip_start(index)
+            except Exception:
+                try:
+                    if index == len(track.clips):
+                        clip = track.clips[index - 1]
+                        prev_cut_frame = track.clip_start(index)
+                except Exception:
+                    continue
             
             # Set cut frame
             if cut_frame == -1:
-                cut_frame = next_cut_frame
-            elif next_cut_frame > cut_frame:
-                cut_frame = next_cut_frame
-                
+                cut_frame = prev_cut_frame
+            elif prev_cut_frame > cut_frame:
+                cut_frame = prev_cut_frame
+            
         return cut_frame
     
     def get_closest_cut_frame(self, track_id, frame):
@@ -993,7 +1008,16 @@ class Sequence:
     def set_track_mute_state(self, track_index, mute_state):
         track = self.tracks[track_index]
         track.mute_state = mute_state
-            
+    
+        # Some older projects might get here without a track gain filter existing
+        if not hasattr(track, "gain_filter"):
+            # Create and add gain filter
+            gain_filter = mlt.Filter(self.profile, "volume")
+            mltrefhold.hold_ref(gain_filter)
+            gain_filter.set("gain", str(track.audio_gain))
+            track.attach(gain_filter)
+            track.gain_filter = gain_filter
+
         if mute_state == 2: # TRACK_MUTE_AUDIO
             if track.id < self.first_video_index:
                 # Audio tracks
