@@ -22,7 +22,6 @@
 This module handles snapping to clip ends while mouse dragging on timeline.
 """
 
-import appconsts
 import compositormodes
 import editorstate
 from editorstate import current_sequence
@@ -33,7 +32,6 @@ _get_frame_for_x_func = None
 _get_x_for_frame_func = None
 
 snapping_on = True
-show_magnet_icon = True
 
 _snap_threshold = 6 # in pixels
 
@@ -82,18 +80,27 @@ def mouse_edit_ended():
 
 #------------------------------------------- utils funcs
 def _get_track_above(track):
+    if track == None:
+        return None # Clip is being dragged outside of tracks area
+        
     if track.id < len(current_sequence().tracks) - 2:
         return current_sequence().tracks[track.id  + 1]
     else:
         return None
         
 def _get_track_below(track):
+    if track == None:
+        return None  # Clip is being dragged outside of tracks area
+        
     if track.id > 1:
         return current_sequence().tracks[track.id  - 1]
     else:
         return None
 
 def _get_track_snapped_x(track, x, frame, frame_x):
+    if track == None:  # Clip is being dragged outside of tracks area
+        return -1
+
     closest_cut_frame = current_sequence().get_closest_cut_frame(track.id, frame)
     if closest_cut_frame == -1:
         return -1
