@@ -33,11 +33,13 @@ from operator import itemgetter
 import threading
 import time
 
+import app
 import appconsts
 import boxmove
 import clipeffectseditor
 import compositeeditor
 import compositormodes
+import cutmode
 import dialogs
 import dialogutils
 import glassbuttons
@@ -61,6 +63,7 @@ import mlttransitions
 import render
 import renderconsumer
 import respaths
+import sequence
 import syncsplitevent
 import updater
 import utils
@@ -110,17 +113,8 @@ def cut_pressed():
     if not timeline_visible():
         updater.display_sequence_in_monitor()   
 
-    # Disable whencut action when it cut clash with ongoing edits
-    if EDIT_MODE() == editorstate.ONE_ROLL_TRIM or EDIT_MODE() == editorstate.TWO_ROLL_TRIM or EDIT_MODE() == editorstate.SLIDE_TRIM:
-        return
-
-    if EDIT_MODE() == editorstate.MULTI_MOVE and multimovemode.edit_data != None:
-        return
-
-    if EDIT_MODE() == editorstate.MULTI_MOVE and multimovemode.edit_data != None:
-        return
-        
-    if boxmove.box_selection_data != None:
+    # Disable cut action when it clashes with ongoing edits
+    if _can_do_cut() == False:
         return
     
     # Get cut frame
@@ -135,7 +129,7 @@ def cut_pressed():
         if track.active == False:
             continue
         
-        if editevent.track_lock_check_and_user_info(track, cut_pressed, "cut"): # so the other tracks get cut...
+        if dialogutils.track_lock_check_and_user_info(track): # so the other tracks get cut...
            continue 
 
         # Get index and clip
@@ -166,6 +160,217 @@ def cut_pressed():
    
     updater.repaint_tline()
 
+def cut_all_pressed():
+    # Disable cut action when it clashes with ongoing edits
+    if _can_do_cut() == False:
+        return
+        
+    tline_frame = PLAYER().current_frame()
+    movemodes.clear_selected_clips()
+    cutmode.cut_all_tracks(tline_frame)
+    
+def _can_do_cut():
+    if EDIT_MODE() == editorstate.ONE_ROLL_TRIM or EDIT_MODE() == editorstate.TWO_ROLL_TRIM or EDIT_MODE() == editorstate.SLIDE_TRIM:
+        return False
+    if EDIT_MODE() == editorstate.MULTI_MOVE and multimovemode.edit_data != None:
+        return False
+    if EDIT_MODE() == editorstate.MULTI_MOVE and multimovemode.edit_data != None:
+        return False
+    if boxmove.box_selection_data != None:
+        return False
+    
+    return True
+        
+def sequence_split_pressed():
+    """
+    Intention of this method is to split a sequence at the current position,
+    reduce it to the the clips on the left side of the cut and move the remains
+    on the right side of the cut to a newly created sequence that is then
+    opened.
+    """
+    # before we start we will ask the user whether he really wants to do, what he
+    # just asked for. The intention of this is to provide some more background
+    # information
+    heading = _("Split to new Sequence at Playhead Position")
+    info = _("Do you realy want to split this sequence into two?\nThis will create a new sequence receiving righthand content of your currently active sequence. Also the same content will be removed from your currently active sequence.\nThe newly created sequence will be opened.\n\n Continue?")
+    dialogutils.warning_confirmation(split_confirmed, heading, info, gui.editor_window.window)
+
+def split_confirmed(dialog, response_id):
+    # so, does the user really want to split the sequence?
+    if response_id != Gtk.ResponseType.ACCEPT:
+        dialog.destroy()
+        return
+
+    # first we destroy the dialog and then we carry out our task
+    dialog.destroy()
+
+    # we determine the frame position
+    tline_frame = PLAYER().current_frame()
+
+    # We start with actually cutting the sequence
+    # actually this poses performance loss, as we do the track loop twice
+    # one in cut_pressed and one in this method
+    # also other operations are repeated
+    cutmode.cut_all_tracks(tline_frame)
+
+    # prepare a data structure that will receive our clips we want to move to
+    # another sequence plus all the information to actually put them at the same
+    # relative position
+    clips_to_move = []
+
+    # we collect the compositors that need to be moved
+    compositors_to_move = _collect_compositors_for_split(tline_frame)
+
+    # now we iterate over all tracks and collect the ones that provide content
+    # after the cut position
+    for i in range(1, len(current_sequence().tracks)):
+        track = get_track(i)
+
+        # Get index and clip - so basically this means, all clips in this
+        # track with this index and above are left of the cut position,
+        # so we gather required information for our new sequence
+        index = track.get_clip_index_at(int(tline_frame))
+
+        # we need to check whether the first clip at cut is a blank clip
+        blank_length = 0
+        if index < len(track.clips):
+            first_clip = track.clips[index]
+            if first_clip.is_blanck_clip == True:
+                # yes, it is a blank clip, therefore we need to modify its length
+                # but only if the clip_start lies before the current frame
+                clip_start = track.clip_start(index)
+                if tline_frame > clip_start:
+                    blank_length = first_clip.clip_out - (tline_frame - clip_start) + 1
+                else:
+                    blank_length = first_clip.clip_out - clip_start + 1
+
+        for j in range(index, len(track.clips)):
+            clip = track.clips[j]
+            data = {
+                "track_index": i,
+                "clip": clip,
+                "clip_in": clip.clip_in,
+                "clip_out": clip.clip_out,
+                "blank_length": blank_length
+            }
+
+            clips_to_move.append(data)
+            # okay, we processed this clip, go on to the next one
+
+    # so we collected all the data for this sequence, now we need to remove
+    # all the clips right hand of the current position
+    data = {
+        "tracks":current_sequence().tracks,
+        "mark_in_frame":tline_frame,
+        "mark_out_frame":PLAYER().get_active_length()
+    }
+
+    action = edit.range_delete_action(data)
+    action.do_edit()
+
+    # so we collected all the data for all tracks
+    # now we create a new sequence and will open that very sequence
+    name = _("sequence_") + str(PROJECT().next_seq_number)
+    sequence.VIDEO_TRACKS_COUNT, sequence.AUDIO_TRACKS_COUNT = current_sequence().get_track_counts()
+    PROJECT().add_named_sequence(name)
+    app.change_current_sequence(len(PROJECT().sequences) - 1)
+
+    # and now, we nee to iterate over the collected clips and add them to
+    # our newly created sequence
+    for i in range(0, len(clips_to_move) - 1):
+        collected = clips_to_move[i]
+        track_index = collected["track_index"]
+
+        # determine the track we need to put the clip in
+        clip = collected["clip"]
+        if clip.is_blanck_clip == True:
+            length = collected["blank_length"]
+            if length == 0:
+                length = clip.clip_length()
+            current_sequence().append_blank(length, get_track(track_index))
+            continue
+
+        #prepare the date and append it to the sequence
+        data = {
+            "track": get_track(track_index),
+            "clip": collected["clip"],
+            "clip_in": collected["clip_in"],
+            "clip_out": collected["clip_out"]
+        }
+
+        action = edit.append_action(data)
+        action.do_edit()
+    
+    # also, we need to add the compositors from our collection
+    _add_compositors_to_split(compositors_to_move)
+    
+    # update time line to show whole range of new sequence
+    updater.zoom_project_length()
+
+def _collect_compositors_for_split(playhead):
+    # there are basically three cases we need to take into consideration
+    # when dealing with compositors.
+    # first: the compositor lies completely before the playhead position
+    # we do not have to deal with those and leave them untouched
+    # compositor.clip_out < playhead position
+    # second: the compositor lies completly behind the playhead position
+    # the compositor needs to be removed from the split sequence and needs to
+    # be moved to the newly created one. we need to create a duplicate and modify
+    # its clip_in and clip_out properties. basically this formula should apply:
+    # new_compositor.clip_in = old_compositor.clip_in - playhead position (same
+    # for clip_out)
+    # third: the playhead position is on a compositor. In this case we need to
+    # split the compositor in two, move one part to the new sequence and leave
+    # the first part in the old one. This can probably be done by simply
+    # modifying the clip_out property of the old compositor.
+    # the new compositor will have clip_in == 0 and
+    # clip_out = oc.clip_out - playhead position.
+
+    # result structure
+    new_compositors = []
+    compositors_to_remove = []
+
+    #  we start with analyzing and collecting the compositors
+    old_compositors = current_sequence().get_compositors()
+    for index in range(0, len(old_compositors)):
+        old_compositor = old_compositors[index]
+        if old_compositor.clip_out < playhead:
+            continue
+        
+        new_compositor = current_sequence().create_compositor(old_compositor.type_id)
+        new_compositor.clone_properties(old_compositor)
+        if old_compositor.clip_in < playhead:
+            new_compositor.set_in_and_out(0, old_compositor.clip_out - playhead)
+            old_compositor.set_in_and_out(old_compositor.clip_in, playhead)
+        else:
+            new_compositor.set_in_and_out(old_compositor.clip_in - playhead, old_compositor.clip_out - playhead)
+            compositors_to_remove.append(old_compositor)
+
+        new_compositor.transition.set_tracks(old_compositor.transition.a_track, old_compositor.transition.b_track)
+        new_compositor.obey_autofollow = old_compositor.obey_autofollow
+        new_compositors.append(new_compositor)
+    
+    # done with collecting all new necessary compositors
+    # now we remove the compositors that are completly after playhead positions
+    # cut compositors have already been reduces in length
+    for index in range(0, len(compositors_to_remove)):
+        old_compositor = compositors_to_remove[index]
+        old_compositor.selected = False
+        data = {"compositor":old_compositor}
+        action = edit.delete_compositor_action(data)
+        action.do_edit()
+    
+    return new_compositors
+
+def _add_compositors_to_split(new_compositors):
+    # now we basically just need to add the compositors in the list to the
+    # right track
+    for index in range(0, len(new_compositors)):
+        new_compositor = new_compositors[index]
+        current_sequence()._plant_compositor(new_compositor)
+        current_sequence().compositors.append(new_compositor)
+    current_sequence().restack_compositors()
+
 def splice_out_button_pressed():
     """
     Removes 1 - n long continuous clip range from track and closes
@@ -182,7 +387,7 @@ def splice_out_button_pressed():
     
     track = get_track(movemodes.selected_track)
 
-    if editevent.track_lock_check_and_user_info(track, splice_out_button_pressed, "splice out"):
+    if dialogutils.track_lock_check_and_user_info(track):
         movemodes.clear_selection_values()
         return
 
@@ -294,7 +499,7 @@ def lift_button_pressed():
                          
     track = get_track(movemodes.selected_track)
 
-    if editevent.track_lock_check_and_user_info(track, lift_button_pressed, "lift"):
+    if dialogutils.track_lock_check_and_user_info(track):
         movemodes.clear_selection_values()
         return
 
@@ -309,10 +514,50 @@ def lift_button_pressed():
 
     updater.repaint_tline()
 
+
+def ripple_delete_button_pressed():
+    print "Ripple delete"
+    if movemodes.selected_track == -1:
+        return
+
+    track = get_track(movemodes.selected_track)
+    
+    delete_range_in = track.clip_start(movemodes.selected_range_in)
+    out_clip = track.clips[movemodes.selected_range_out]
+    delete_range_out = track.clip_start(movemodes.selected_range_out) + out_clip.clip_out - out_clip.clip_in + 1 # +1 out incl
+    delete_range_length = delete_range_out - delete_range_in
+    
+    ripple_data = multimovemode.MultimoveData(track, delete_range_out, True, False)
+    ripple_data.build_ripple_data(track.id, delete_range_length, movemodes.selected_range_in)
+    available_from_range_out = ripple_data.max_backwards
+
+    ripple_data = multimovemode.MultimoveData(track, delete_range_in, True, False)
+    ripple_data.build_ripple_data(track.id, delete_range_length, movemodes.selected_range_in)
+    available_from_range_in = ripple_data.max_backwards
+
+    if available_from_range_in < delete_range_length or available_from_range_out < delete_range_length:
+        overwrite_track = ripple_data.get_overwrite_data(delete_range_length)
+        primary_txt = _("Can't do Ripple Delete!")
+        secondary_txt = _("Seleted Ripple Delete would cause an overwrite and that is not permitted for this edit action.\n\nOverwrite would happen on at track <b>") + utils.get_track_name(overwrite_track, current_sequence()) + "</b>."
+        parent_window = gui.editor_window.window
+        dialogutils.info_message(primary_txt, secondary_txt, parent_window)
+        return 
+
+    # Do ripple delete
+    data = {"track":track,
+            "from_index":movemodes.selected_range_in,
+            "to_index":movemodes.selected_range_out,
+            "multi_data":ripple_data,
+            "edit_delta":-delete_range_length}
+    edit_action = edit.ripple_delete_action(data)
+    edit_action.do_edit()
+    
+    _splice_out_done_update()
+    
 def insert_button_pressed():
     track = current_sequence().get_first_active_track()
 
-    if editevent.track_lock_check_and_user_info(track, insert_button_pressed, "insert"):
+    if dialogutils.track_lock_check_and_user_info(track):
         return
 
     tline_pos =_current_tline_frame()
@@ -328,7 +573,7 @@ def insert_button_pressed():
 def append_button_pressed():
     track = current_sequence().get_first_active_track()
 
-    if editevent.track_lock_check_and_user_info(track, append_button_pressed, "insert"):
+    if dialogutils.track_lock_check_and_user_info(track):
         return
 
     tline_pos = track.get_length()
@@ -351,7 +596,7 @@ def three_point_overwrite_pressed():
 
     # Get data
     track = get_track(movemodes.selected_track)
-    if editevent.track_lock_check_and_user_info(track, three_point_overwrite_pressed, "3 point overwrite"):
+    if dialogutils.track_lock_check_and_user_info(track):
         return
     
     range_start_frame = track.clip_start(movemodes.selected_range_in)
@@ -396,7 +641,7 @@ def three_point_overwrite_pressed():
 def range_overwrite_pressed():
     # Get data
     track = current_sequence().get_first_active_track()
-    if editevent.track_lock_check_and_user_info(track, range_overwrite_pressed, "range overwrite"):
+    if dialogutils.track_lock_check_and_user_info(track):
         return
 
     # Get over clip and check it overwrite range area
@@ -1289,7 +1534,7 @@ class ReRenderderAllWindow:
         self.rerender_list = rerender_list
         self.rendered_items = []
         self.encoding_selections = encoding_selections
-        self.dialog = Gtk.Dialog("Rerender all Rendered Transitions / Fades",
+        self.dialog = Gtk.Dialog(_("Rerender all Rendered Transitions / Fades").encode('utf-8'),
                          gui.editor_window.window,
                          Gtk.DialogFlags.MODAL | Gtk.DialogFlags.DESTROY_WITH_PARENT,
                          (_("Cancel").encode('utf-8'), Gtk.ResponseType.REJECT))
@@ -1670,7 +1915,7 @@ def do_compositor_data_paste(paste_objs):
 def _timeline_has_focus(): # copied from keyevents.by. maybe put in utils?
     if(gui.tline_canvas.widget.is_focus()
        or gui.tline_column.widget.is_focus()
-       or gui.editor_window.modes_selector.widget.is_focus()
+       or gui.editor_window.tool_selector.widget.is_focus()
        or (gui.pos_bar.widget.is_focus() and timeline_visible())
        or gui.tline_scale.widget.is_focus()
        or glassbuttons.focus_group_has_focus(glassbuttons.DEFAULT_FOCUS_GROUP)):
