@@ -45,14 +45,17 @@ import time
 import threading
 import unicodedata
 
+import appconsts
 import dialogutils
 import editorstate
 import editorpersistance
+import gui
 import guiutils
 import mltenv
 import mltprofiles
 import mlttransitions
 import mltfilters
+import processutils
 import persistance
 import respaths
 import renderconsumer
@@ -335,13 +338,16 @@ def main(root_path, force_launch=False):
     # Init gtk threads
     Gdk.threads_init()
     Gdk.threads_enter()
-
-    # Request dark them if so desired
-    if editorpersistance.prefs.dark_theme == True:
+       
+    editorpersistance.load()
+    if editorpersistance.prefs.theme != appconsts.LIGHT_THEME:
         Gtk.Settings.get_default().set_property("gtk-application-prefer-dark-theme", True)
-
+        if editorpersistance.prefs.theme == appconsts.FLOWBLADE_THEME:
+            gui.apply_gtk_css()
+            
     repo = mlt.Factory().init()
-
+    processutils.prepare_mlt_repo(repo)
+    
     # Set numeric locale to use "." as radix, MLT initilizes this to OS locale and this causes bugs 
     locale.setlocale(locale.LC_NUMERIC, 'C')
 
@@ -1119,10 +1125,14 @@ def single_render_main(root_path):
     Gdk.threads_enter()
 
     # Request dark them if so desired
-    if editorpersistance.prefs.dark_theme == True:
+    editorpersistance.load()
+    if editorpersistance.prefs.theme != appconsts.LIGHT_THEME:
         Gtk.Settings.get_default().set_property("gtk-application-prefer-dark-theme", True)
+        if editorpersistance.prefs.theme == appconsts.FLOWBLADE_THEME:
+            gui.apply_gtk_css()
 
     repo = mlt.Factory().init()
+    processutils.prepare_mlt_repo(repo)
 
     # Set numeric locale to use "." as radix, MLT initilizes this to OS locale and this causes bugs 
     locale.setlocale(locale.LC_NUMERIC, 'C')
