@@ -30,7 +30,6 @@ from gi.repository import Pango
 import cairo
 import locale
 import mlt
-import numpy as np
 import os
 import re
 import shutil
@@ -53,7 +52,7 @@ import mltprofiles
 import mlttransitions
 import mltfilters
 import positionbar
-import render
+import processutils
 import respaths
 import renderconsumer
 import toolguicomponents
@@ -100,7 +99,7 @@ _hamburger_menu = Gtk.Menu()
 
 #-------------------------------------------------- launch and inits
 def test_availablity():
-    if os.path.exists("/usr/bin/gmic") == True:
+    if os.path.exists("/usr/bin/gmic") == True or os.path.exists("/app/bin/gmic") == True: # File system and flatpak
         print "G'MIC found"
         global _gmic_found
         _gmic_found = True
@@ -174,7 +173,7 @@ def main(root_path, force_launch=False):
     # Write stdout to log file
     sys.stdout = open(utils.get_hidden_user_dir_path() + "log_gmic", 'w')
     print "G'MIC version:", str(_gmic_version)
-        
+
     # Init gmic tool session dirs
     if os.path.exists(get_session_folder()):
         shutil.rmtree(get_session_folder())
@@ -183,11 +182,13 @@ def main(root_path, force_launch=False):
 
     init_frames_dirs()
 
-    # Load editor prefs and list of recent projects
+    # Load editor prefs and apply themes
     editorpersistance.load()
-    if editorpersistance.prefs.dark_theme == True:
-        respaths.apply_dark_theme()
-
+    if editorpersistance.prefs.theme != appconsts.LIGHT_THEME:
+        Gtk.Settings.get_default().set_property("gtk-application-prefer-dark-theme", True)
+        if editorpersistance.prefs.theme == appconsts.FLOWBLADE_THEME:
+            gui.apply_gtk_css()
+            
     # Init translations module with translations data
     translations.init_languages()
     translations.load_filters_translations()
@@ -195,17 +196,31 @@ def main(root_path, force_launch=False):
 
     # Load preset gmic scripts
     gmicscript.load_preset_scripts_xml()
-    
+
     # Init gtk threads
     Gdk.threads_init()
     Gdk.threads_enter()
 
-    # Request dark them if so desired
-    if editorpersistance.prefs.dark_theme == True:
+    # Set monitor sizes
+    scr_w = Gdk.Screen.width()
+    scr_h = Gdk.Screen.height()
+    editorstate.SCREEN_WIDTH = scr_w
+    editorstate.SCREEN_HEIGHT = scr_h
+    if editorstate.screen_size_large_height() == True and editorstate.screen_size_small_width() == False:
+        global MONITOR_WIDTH, MONITOR_HEIGHT
+        MONITOR_WIDTH = 650
+        MONITOR_HEIGHT = 400 # initial value, this gets changed when material is loaded
+
+    # Themes
+    if editorpersistance.prefs.theme != appconsts.LIGHT_THEME:
+        respaths.apply_dark_theme()
         Gtk.Settings.get_default().set_property("gtk-application-prefer-dark-theme", True)
+        if editorpersistance.prefs.theme == appconsts.FLOWBLADE_THEME:
+            gui.apply_gtk_css()
 
     repo = mlt.Factory().init()
-
+    processutils.prepare_mlt_repo(repo)
+    
     # Set numeric locale to use "." as radix, MLT initilizes this to OS locale and this causes bugs 
     locale.setlocale(locale.LC_NUMERIC, 'C')
 
@@ -404,7 +419,6 @@ def load_script_dialog(callback):
     dialog.connect('response', callback)
     dialog.show()
 
-
 def _load_script_dialog_callback(dialog, response_id):
     if response_id == Gtk.ResponseType.ACCEPT:
         filename = dialog.get_filenames()[0]
@@ -634,8 +648,8 @@ class GmicWindow(Gtk.Window):
         pos_bar_frame = Gtk.Frame()
         pos_bar_frame.add(self.pos_bar.widget)
         pos_bar_frame.set_shadow_type(Gtk.ShadowType.ETCHED_IN)
-        pos_bar_frame.set_margin_top(5)
-        pos_bar_frame.set_margin_bottom(4)
+        pos_bar_frame.set_margin_top(10)
+        pos_bar_frame.set_margin_bottom(9)
         pos_bar_frame.set_margin_left(6)
         pos_bar_frame.set_margin_right(2)
         
@@ -664,7 +678,8 @@ class GmicWindow(Gtk.Window):
         preview_panel.pack_start(control_panel, False, False, 0)
         preview_panel.set_margin_bottom(8)
 
-        # Script area
+        # Script area 
+        # Script selector menu launcher
         self.preset_label = Gtk.Label()
         self.present_event_box = Gtk.EventBox()
         self.present_event_box.add(self.preset_label)
@@ -1002,36 +1017,6 @@ class GmicWindow(Gtk.Window):
  
         self.update_encode_sensitive()
 
-"""
-class PressLaunch:
-    def __init__(self, callback, w=22, h=22):
-        self.widget = cairoarea.CairoDrawableArea2( w, 
-                                                    h, 
-                                                    self._draw)
-        self.widget.press_func = self._press_event
-        self.callback = callback
-        self.sensitive = True
-
-    def set_sensitive(self, value):
-        self.sensitive = value
-        
-    def _draw(self, event, cr, allocation):      
-        cr.move_to(7, 13)
-        cr.line_to(12, 18)
-        cr.line_to(17, 13)
-        cr.close_path()
-        if editorpersistance.prefs.dark_theme == False:
-            cr.set_source_rgb(0, 0, 0)
-        else:
-            cr.set_source_rgb(0.66, 0.66, 0.66)
-        cr.fill()
-        
-    def _press_event(self, event):
-        if self.sensitive == False:
-           return 
-
-        self.callback(self.widget, event)
-"""
 
 #------------------------------------------------- global key listener
 def _global_key_down_listener(widget, event):
