@@ -47,9 +47,14 @@ def init_languages():
 
     if editorstate.app_running_from == editorstate.RUNNING_FROM_INSTALLATION:
         # Use /usr/share/locale first if available and running from installation
+        # Look for installed translation in distro install
         if os.path.isfile("/usr/share/locale/fi/LC_MESSAGES/flowblade.mo"): # fi is the translation controlled by program author
             print "Found translations at /usr/share/locale, using those."
             locale_path = "/usr/share/locale/"
+        #  Look for installed translations in flatpak install 
+        elif os.path.isfile("/app/share/flowblade/Flowblade/locale/fi/LC_MESSAGES/flowblade.mo"): # fi is the translation controlled by program author
+            print "Found translations at /app/share/flowblade/Flowblade/locale, using those."
+            locale_path = "app/share/flowblade/Flowblade/locale"
         else:
             print "Translations at /usr/share/locale were not found, using program root directory translations."
             locale_path = respaths.LOCALE_PATH
@@ -76,7 +81,7 @@ def init_languages():
         lang = gettext.translation(APP_NAME, locale_path, languages=langs, fallback=True)
 
     # Un-comment for translations tests
-    #lang = gettext.translation(APP_NAME, locale_path, languages=["fi"], fallback=True)
+    #lang = gettext.translation(APP_NAME, locale_path, languages=["ru"], fallback=True)
 
     lang.install(APP_NAME) # makes _() a build-in available in all modules without imports
 
@@ -240,10 +245,12 @@ def load_filters_translations():
     filter_names["Lift Gain Gamma"] = _("Lift Gain Gamma")
     filter_names["Image Grid"] = _("Image Grid")
 
+    # Later
     filter_names["Color Lift Gain Gamma"] = _("Color Lift Gain Gamma")
     filter_names["Color Channel Mixer"] = _("Color Channel Mixer")
     filter_names["Lens Correction AV"] = _("Lens Correction AV")
     filter_names["Perspective"] = _("Perspective")
+    filter_names["Translate"] = _("Translate")
     
     # param names
     global param_names
