@@ -21,6 +21,7 @@
 """
 Module contains GUI update routines.
 """
+import time
 
 from gi.repository import Gtk
 from gi.repository import Gdk
@@ -36,6 +37,7 @@ from editorstate import PLAYER
 from editorstate import PROJECT
 from editorstate import timeline_visible
 import editorpersistance
+import kftoolmode
 import monitorevent
 import utils
 import respaths
@@ -121,13 +123,6 @@ def refresh_player(e):
 
 # --------------------------------- window 
 def window_resized():
-    # This can get async called from window "size-allocate" signal 
-    # during project load before project.c_seq has been build
-    if not(hasattr(editorstate.project, "c_seq")):
-        return
-    if editorstate.project.c_seq == None:
-        return
-
     # Resize track heights so that all tracks are displayed
     current_sequence().resize_tracks_to_fit(gui.tline_canvas.widget.get_allocation())
     
@@ -187,7 +182,21 @@ def tline_scrolled(adjustment):
     else:
         tlinewidgets.pos = 0
     repaint_tline()
+
+def maybe_move_playback_tline_range(current_frame):
+    # Prefs check
+    if editorpersistance.prefs.playback_follow_move_tline_range == False:
+        return False
     
+    moved = False
+    last_frame = tlinewidgets.get_last_tline_view_frame()
+    if current_frame > last_frame:
+        moved = True
+        adj_value = float(last_frame + 1) / float(current_sequence().get_length()) * 100.0
+        gui.tline_scroll.set_value(adj_value)
+    
+    return moved
+ 
 def center_tline_to_current_frame():
     """
     Sets scroll widget adjustment to place current frame in the middle of display.
@@ -272,9 +281,11 @@ def mouse_scroll_zoom(event):
         if not(event.get_state() & Gdk.ModifierType.CONTROL_MASK):
             do_zoom = False
 
-    if do_zoom == True:
+    if do_zoom == True: # Uh, were doing scroll here.
         adj = gui.tline_scroll.get_adjustment()
         incr = adj.get_step_increment()
+        if editorpersistance.prefs.scroll_horizontal_dir_up_forward == False:
+            incr = -incr
         if event.direction == Gdk.ScrollDirection.UP:
             adj.set_value(adj.get_value() + incr)
         else:
@@ -320,7 +331,6 @@ def display_clip_in_monitor(clip_monitor_currently_active=False):
     Sets mltplayer producer to be video file clip and updates GUI.
     """
     if MONITOR_MEDIA_FILE() == None:
-        gui.editor_window.clip_editor_b.set_active(False)
         return
 
     global save_monitor_frame
@@ -330,7 +340,6 @@ def display_clip_in_monitor(clip_monitor_currently_active=False):
     if not editorstate.current_is_move_mode():
         set_clip_edit_mode_callback()
 
-    gui.clip_editor_b.set_sensitive(True)
     editorstate._timeline_displayed = False
 
     # Save timeline pos if so directed.
@@ -403,21 +412,19 @@ def display_clip_in_monitor(clip_monitor_currently_active=False):
     gui.pos_bar.widget.grab_focus()
     gui.media_list_view.widget.queue_draw()
     
-    if editorpersistance.prefs.auto_play_in_clip_monitor == True:
-        PLAYER().start_playback()
+    # feature removed currently
+    #if editorpersistance.prefs.auto_play_in_clip_monitor == True:
+    #    PLAYER().start_playback()
     
+    gui.monitor_switch.widget.queue_draw()
     repaint_tline()
 
 def display_monitor_clip_name():#we're displaying length and range length also
-    tc_info = utils.get_tc_string(gui.pos_bar.producer.get_length()) 
-    if  MONITOR_MEDIA_FILE().mark_in != -1 and MONITOR_MEDIA_FILE().mark_out != -1:
-        clip_length = utils.get_tc_string(MONITOR_MEDIA_FILE().mark_out - MONITOR_MEDIA_FILE().mark_in + 1) #+1 out incl.
-        tc_info = tc_info + "  ][ " + str(clip_length)
-    else:
-        tc_info = tc_info + "  ][ --:--:--:--" 
+    clip_len = utils.get_tc_string(gui.pos_bar.producer.get_length())
+    range_info = _get_marks_range_info_text(MONITOR_MEDIA_FILE().mark_in, MONITOR_MEDIA_FILE().mark_out)
 
-    gui.editor_window.monitor_source.set_text(MONITOR_MEDIA_FILE().name)
-    gui.editor_window.info1.set_text(tc_info)
+    gui.editor_window.monitor_source.set_text(MONITOR_MEDIA_FILE().name + " - " + clip_len)
+    gui.editor_window.info1.set_text(range_info)
 
 def display_sequence_in_monitor():
     """
@@ -426,13 +433,7 @@ def display_sequence_in_monitor():
     """
     if PLAYER() == None: # this method gets called too early when initializing, hack fix.
         return
-    
-    # If this gets called without user having pressed 'Timeline' button we'll 
-    # programmatically press it to recall this method to have the correct button down.
-    if gui.sequence_editor_b.get_active() == False:
-        gui.sequence_editor_b.set_active(True)
-        return
-        
+           
     editorstate._timeline_displayed = True
 
     # Clear hidden track that has been displaying monitor clip
@@ -450,38 +451,48 @@ def display_sequence_in_monitor():
     gui.pos_bar.update_display_from_producer(PLAYER().producer)
     display_marks_tc()
 
+    gui.monitor_switch.widget.queue_draw()
     repaint_tline()
 
 def update_seqence_info_text():
     name = editorstate.current_sequence().name
-    profile_desc = editorstate.current_sequence().profile.description()
-    
-    if editorpersistance.prefs.show_sequence_profile:
-        gui.editor_window.monitor_source.set_text(name + "  -  " + profile_desc)
-    else:
-        gui.editor_window.monitor_source.set_text(name)
-    
     prog_len = PLAYER().producer.get_length()
     if prog_len < 2: # # to 'fix' the single frame black frame at start, will bug for actual 1 frame sequences
         prog_len = 0
-    
-    range_len = PLAYER().producer.mark_out - PLAYER().producer.mark_in + 1 # +1, out incl.
     tc_info = utils.get_tc_string(prog_len)
-    if PLAYER().producer.mark_in != -1 and PLAYER().producer.mark_out != -1:
-        tc_info = tc_info + "  ][ " + utils.get_tc_string(range_len)
+
+    gui.editor_window.monitor_source.set_text(name + "  -  " + tc_info)
+    range_info = _get_marks_range_info_text(PLAYER().producer.mark_in, PLAYER().producer.mark_out)
+    gui.editor_window.info1.set_text(range_info)
+
+def _get_marks_range_info_text(mark_in, mark_out):
+    if editorstate.screen_size_small_width() == False:
+        if mark_in != -1:
+            range_info = "] " + utils.get_tc_string(mark_in)
+        else:
+            range_info = "] --:--:--:--" 
+
+        if mark_out != -1:
+            range_info = range_info + "   [ " + utils.get_tc_string(mark_out) + "   "
+        else:
+            range_info = range_info + "   [ --:--:--:--"  + "   "
     else:
-        tc_info = tc_info + "  ][ --:--:--:--" 
-        
-    gui.editor_window.info1.set_text(tc_info)
+        range_info = ""
+
+    range_len = mark_out - mark_in + 1 # +1, out incl.
+    if mark_in != -1 and mark_out != -1:
+        range_info = range_info + "][ " + utils.get_tc_string(range_len)
+    else:
+        range_info = range_info + "][ --:--:--:--" 
+    
+    return range_info
 
 def switch_monitor_display():
     monitorevent.stop_pressed()
     if editorstate.MONITOR_MEDIA_FILE() == None:
         return
     if editorstate._timeline_displayed == True:
-        gui.editor_window.clip_editor_b.set_active(True)
-    else:
-        gui.editor_window.sequence_editor_b.set_active(True)
+        gui.monitor_switch.widget.queue_draw()
 
 def display_tline_cut_frame(track, index):
     """
@@ -512,15 +523,11 @@ def set_and_display_monitor_media_file(media_file):
     """
     editorstate._monitor_media_file = media_file
     
-    # If we're already displaying clip monitor, then already button is down we call display_clip_in_monitor(..)
-    # directly, but dont save position because we're not displaying now.
-    #
-    # If we're displaying sequence we do programmatical click on "Clip" button 
-    # to display clip via it's signal listener. 
-    if gui.editor_window.clip_editor_b.get_active() == True:
-        display_clip_in_monitor(clip_monitor_currently_active = True)
+    if editorstate.timeline_visible() == True:
+        display_clip_in_monitor()
     else:
-        gui.editor_window.clip_editor_b.set_active(True)
+        display_clip_in_monitor(clip_monitor_currently_active = True)
+
 
 # --------------------------------------- frame displayes
 def update_frame_displayers(frame):
@@ -538,6 +545,8 @@ def update_frame_displayers(frame):
     norm_pos = frame / float(producer_length) 
     gui.pos_bar.set_normalized_pos(norm_pos)
 
+    kftoolmode.update_clip_frame(frame)
+    
     gui.tline_scale.widget.queue_draw()
     gui.tline_canvas.widget.queue_draw()
     gui.big_tc.queue_draw()
@@ -557,10 +566,7 @@ def display_marks_tc():
     else:
         update_seqence_info_text()
 
-# ----------------------------------------------- clip editors
-def clip_removed_during_edit(clip):
-    clipeffectseditor.clip_removed_during_edit(clip)
-    
+# ----------------------------------------------- clip editors    
 def clear_clip_from_editors(clip):
     if clipeffectseditor.clip == clip:
         clipeffectseditor.clear_clip()
@@ -575,7 +581,8 @@ def open_clip_in_effects_editor(data):
 # ----------------------------------------- edit modes
 def set_trim_mode_gui():
     """
-    Called when user selects trim mode
+    Called when user selects trim mode.
+    This does not actually set GUI, just makes sure we are displaying timeline since we are ready to strart trimmng sometring in it.
     """
     display_sequence_in_monitor()
 
@@ -606,9 +613,3 @@ def set_transition_render_edit_menu_items_sensitive(range_start, range_end):
         render_transition.set_sensitive(False)
         render_fade.set_sensitive(False)
 
-"""
-# ------------------------------------------------ notebook
-def switch_notebook_panel(index):
-    gui.middle_notebook.set_current_page(index)
-
-"""
