@@ -25,7 +25,7 @@ import time
 
 import gi
 gi.require_version('Gtk', '3.0')
-from gi.repository import Gtk
+from gi.repository import Gtk, GLib
 
 import math
 import md5
@@ -98,6 +98,14 @@ class LaunchThread(threading.Thread):
 def fps():
     return editorstate.PROJECT().profile.fps()
 
+def get_fps_str_with_two_decimals(fps_str):
+    fps_sides = fps_str.split(".")
+    try:
+        decimals = fps_sides[1][0:2]
+    except:
+        decimals = fps_sides[1]
+    return fps_sides[0] + "." + decimals
+    
 def clip_length_string(length):
     """ 
     Returns length string for length in frames.
@@ -376,7 +384,10 @@ def int_to_hex_str(n):
 
 def int_to_hex(n):
     # Input value range 0 - 255, 00 - ff
-    return hex(n)[2:]
+    val_str = hex(n)[2:]
+    if len(val_str) == 1:
+        val_str = "0" + val_str
+    return val_str
 
 def gdk_color_str_to_mlt_color_str(gdk_color_str):
     raw_r, raw_g, raw_b = hex_to_rgb(gdk_color_str)
@@ -416,16 +427,6 @@ def get_unique_name_for_audio_levels_file(media_file_path, profile):
     return file_name
     
 def get_hidden_user_dir_path():
-    """ 
-    this is nit for now, reactiva if flatpack snadboxing is tried.
-    
-    if editorstate.use_xdg:
-        return os.path.join( 
-                            os.getenv("XDG_CONFIG_HOME", os.path.join(os.getenv("HOME"),".config")),
-                            "flowblade/")
-    else:
-    """
-    
     return os.getenv("HOME") + "/.flowblade/"
 
 def get_phantom_disk_cache_folder():
@@ -434,6 +435,33 @@ def get_phantom_disk_cache_folder():
 def get_hidden_screenshot_dir_path():
     return get_hidden_user_dir_path() + "screenshot/"
 
+def get_config_folder():
+    if editorstate.use_xdg:
+        return xdg_config_home()
+    else:
+        return get_hidden_user_dir_path()
+
+def get_data_folder():
+    if editorstate.use_xdg:
+        return xdg_data_home()
+    else:
+        return get_hidden_user_dir_path()
+        
+def get_cache_folder():   
+    if editorstate.use_xdg:
+        return xdg_cache_home()
+    else:
+        return get_hidden_user_dir_path()
+
+def xdg_config_home():
+    return os.path.join(GLib.get_user_config_dir(), "flowblade")
+    
+def xdg_data_home():
+    return os.path.join(GLib.get_user_data_dir(), "flowblade")
+
+def xdg_cache_home():
+    return os.path.join(GLib.get_user_cache_dir(), "flowblade")
+
 def get_img_seq_glob_lookup_name(asset_file_name):
     parts1 = asset_file_name.split("%")
     start = parts1[0]
