@@ -24,16 +24,18 @@ from distutils.core import setup
 
 # FLOWBLADE distutils setup.py script.
 
-install_data = [('share/applications', ['installdata/flowblade.desktop']),
-                ('share/pixmaps', ['installdata/flowblade.png']),
-                ('share/mime/packages',['installdata/flowblade.xml']),
+install_data = [('share/applications', ['installdata/io.github.jliljebl.Flowblade.desktop']),
+                ('share/appdata', ['installdata/io.github.jliljebl.Flowblade.appdata.xml']),
+                ('share/icons/hicolor/128x128/apps', ['installdata/io.github.jliljebl.Flowblade.png']),
+                ('share/mime/packages',['installdata/io.github.jliljebl.Flowblade.xml']),
                 ('lib/mime/packages',['installdata/flowblade']),
                 ('share/man/man1',['installdata/flowblade.1'])]
 
 flowblade_package_data = ['res/filters/*.xml','res/filters/wipes/*','res/img/*',
                           'res/profiles/*','res/render/renderencoding.xml',
                           'res/patternproducer/*','res/help/*','locale/Flowblade/*',
-                          'res/proxyprofiles/*','res/darktheme/*','launch/*','res/gmic/*','res/shortcuts/*']
+                          'res/proxyprofiles/*','res/darktheme/*','launch/*','res/gmic/*',
+                          'res/shortcuts/*','res/css/*','res/css/assests/*','res/css/sass/*']
 
 locale_files = []
 for filepath in glob.glob("Flowblade/locale/*/LC_MESSAGES/*"):
@@ -41,7 +43,7 @@ for filepath in glob.glob("Flowblade/locale/*/LC_MESSAGES/*"):
     locale_files.append(filepath)
 
 setup(  name='flowblade',
-        version='1.16.0',
+        version='2.0.0',
         author='Janne Liljeblad',
         author_email='janne.liljeblad at gmail dot com',
         description='Non-linear video editor',
